@@ -18,6 +18,7 @@ CREATE TABLE book
 	callnumber	     VARCHAR(64),
 	category	     TEXT NOT NULL,
 	condition 	     TEXT,
+	date_of_reform	     VARCHAR(32),
 	description	     TEXT NOT NULL,
 	deweynumber	     VARCHAR(64),
 	edition		     VARCHAR(8) NOT NULL,
@@ -32,11 +33,13 @@ CREATE TABLE book
 	monetary_units	     VARCHAR(64) NOT NULL DEFAULT 'UNKNOWN',
 	multivolume_set_isbn VARCHAR(32),
 	myoid		     BIGSERIAL UNIQUE,
+	origin		     TEXT,
 	originality 	     TEXT,
 	pdate		     VARCHAR(32) NOT NULL,
 	place		     TEXT NOT NULL,
 	price		     NUMERIC(10, 2) NOT NULL DEFAULT 0.00,
 	publisher	     TEXT NOT NULL,
+	purchase_date	     VARCHAR(32),
 	quantity	     INTEGER NOT NULL DEFAULT 1,
 	target_audience	     TEXT,
 	title		     TEXT NOT NULL,
@@ -52,6 +55,7 @@ CREATE TABLE book_copy_info
 	copyid		 VARCHAR(64) NOT NULL,
 	item_oid	 BIGINT NOT NULL,
 	myoid		 BIGSERIAL UNIQUE,
+	notes		 TEXT,
 	originality	 TEXT,
 	status		 TEXT,
 	FOREIGN KEY (item_oid) REFERENCES book (myoid) ON DELETE CASCADE,
@@ -103,6 +107,7 @@ CREATE TABLE cd_copy_info
 	copyid		 VARCHAR(64) NOT NULL,
 	item_oid	 BIGINT NOT NULL,
 	myoid		 BIGSERIAL UNIQUE,
+	notes		 TEXT,
 	status		 TEXT,
 	FOREIGN KEY (item_oid) REFERENCES cd (myoid) ON DELETE CASCADE,
 	PRIMARY KEY (item_oid, copyid)
@@ -156,6 +161,7 @@ CREATE TABLE dvd_copy_info
 	copyid		 VARCHAR(64) NOT NULL,
 	item_oid	 BIGINT NOT NULL,
 	myoid		 BIGSERIAL UNIQUE,
+	notes		 TEXT,
 	status		 TEXT,
 	FOREIGN KEY (item_oid) REFERENCES dvd (myoid) ON DELETE CASCADE,
 	PRIMARY KEY (item_oid, copyid)
@@ -229,6 +235,7 @@ CREATE TABLE journal_copy_info
 	copyid		 VARCHAR(64) NOT NULL,
 	item_oid	 BIGINT NOT NULL,
 	myoid		 BIGSERIAL UNIQUE,
+	notes		 TEXT,
 	status		 TEXT,
 	FOREIGN KEY (item_oid) REFERENCES journal (myoid) ON DELETE CASCADE,
 	PRIMARY KEY (item_oid, copyid)
@@ -281,6 +288,7 @@ CREATE TABLE magazine_copy_info
 	copyid		 VARCHAR(64) NOT NULL,
 	item_oid	 BIGINT NOT NULL,
 	myoid		 BIGSERIAL UNIQUE,
+	notes		 TEXT,
 	status		 TEXT,
 	FOREIGN KEY (item_oid) REFERENCES magazine (myoid) ON DELETE CASCADE,
 	PRIMARY KEY (item_oid, copyid)
@@ -369,6 +377,7 @@ CREATE TABLE videogame_copy_info
 	copyid		 VARCHAR(64) NOT NULL,
 	item_oid	 BIGINT NOT NULL,
 	myoid		 BIGSERIAL UNIQUE,
+	notes		 TEXT,
 	status		 TEXT,
 	FOREIGN KEY (item_oid) REFERENCES videogame (myoid) ON DELETE CASCADE,
 	PRIMARY KEY (item_oid, copyid)
