@@ -29,7 +29,7 @@
 #define _BIBLIOTEQ_H_
 
 #define BIBLIOTEQ_GUEST_ACCOUNT "xbook_guest"
-#define BIBLIOTEQ_VERSION "2023.07.20"
+#define BIBLIOTEQ_VERSION "2024.03.25"
 
 #include "biblioteq_batch_activities.h"
 #include "biblioteq_book.h"
@@ -41,6 +41,7 @@
 #include "biblioteq_grey_literature.h"
 #include "biblioteq_import.h"
 #include "biblioteq_magazine.h"
+#include "biblioteq_magic.h"
 #include "biblioteq_misc_functions.h"
 #include "biblioteq_myqstring.h"
 #include "biblioteq_numeric_table_item.h"
@@ -62,6 +63,7 @@
 class biblioteq_documentationwindow;
 class biblioteq_files;
 class biblioteq_otheroptions;
+class biblioteq_query_history;
 class biblioteq_sqlite_merge_databases;
 class swifty;
 
@@ -298,11 +300,6 @@ class biblioteq: public QMainWindow
   static const int VIEW_ONLY = 1;
   biblioteq(void);
   ~biblioteq();
-  QHash<QAction *, QPointer<biblioteq_documentationwindow> > m_documentation;
-  QHash<QAction *, QPointer<biblioteq_documentationwindow> > m_releaseNotes;
-  QPointer<QMenu> m_configToolMenu;
-  QPointer<biblioteq_documentationwindow> m_contributors;
-  QString m_unaccent;
   QColor availabilityColor(const QString &itemType) const;
   QColor itemMandatoryFieldColor(void) const;
   QColor itemQueryResultColor(void) const;
@@ -326,6 +323,7 @@ class biblioteq: public QMainWindow
   QString unaccent(void) const;
   QStringList getSRUNames(void) const;
   QStringList getZ3950Names(void) const;
+  QStringList selectedISBN10s(void) const;
   QVariant setting(const QString &name) const;
   QVector<QString> getBBColumnIndexes(void) const;
   Ui_mainWindow getUI(void) const;
@@ -458,13 +456,13 @@ class biblioteq: public QMainWindow
   QActionGroup *m_menuCategoryActionGroup;
   QDialog *m_branch_diag;
   QDialog *m_pass_diag;
+  QHash<QAction *, QPointer<biblioteq_documentationwindow> > m_documentation;
+  QHash<QAction *, QPointer<biblioteq_documentationwindow> > m_releaseNotes;
   QHash<QString, QString> m_amazonImages;
   QHash<QString, QString> m_openLibraryImages;
   QHash<QString, QString> m_openLibraryItems;
   QHash<QString, QString> m_otherImages;
   QHash<QString, QString> m_selectedBranch;
-  QLabel *m_connected_bar_label;
-  QLabel *m_status_bar_label;
   QList<QTableWidgetItem *> m_findList;
   QMainWindow *m_admin_diag;
   QMainWindow *m_all_diag;
@@ -477,8 +475,14 @@ class biblioteq: public QMainWindow
   QMessageBox *m_about;
   QMultiMap<QString, QHash<QString, QString> > m_z3950Maps;
   QPair<QColor, QColor> m_aboutColors;
+  QPointer<QLabel> m_connected_bar_label;
+  QPointer<QLabel> m_status_bar_label;
+  QPointer<QMenu> m_configToolMenu;
   QPointer<QMenu> m_menu;
+  QPointer<QToolButton> m_error_bar_label;
   QPointer<biblioteq_dbenumerations> db_enumerations;
+  QPointer<biblioteq_documentationwindow> m_contributors;
+  QPointer<biblioteq_query_history> m_queryHistory;
   QPointer<biblioteq_sqlite_merge_databases> m_sqliteMergeDatabases;
   QSqlDatabase m_db;
   QSqlQuery *m_searchQuery;
@@ -487,10 +491,11 @@ class biblioteq: public QMainWindow
   QString m_lastSearchStr;
   QString m_previousTypeFilter;
   QString m_roles;
+  QString m_unaccent;
   QStringList m_deletedAdmins;
+  QStringList m_specialExecutablesIcons;
   QTextBrowser *m_printPreview;
   QTimer m_aboutTimer;
-  QToolButton *m_error_bar_label;
   QVector<QString> m_abColumnHeaderIndexes;
   QVector<QString> m_bbColumnHeaderIndexes;
   QVector<QString> m_historyColumnHeaderIndexes;
@@ -505,6 +510,7 @@ class biblioteq: public QMainWindow
   biblioteq_batch_activities *m_batchActivities;
   biblioteq_files *m_files;
   biblioteq_import *m_import;
+  biblioteq_magic *m_magic;
   biblioteq_otheroptions *m_otheroptions;
   bool m_allSearchShown;
   bool m_membersWasRefreshed;
@@ -533,13 +539,15 @@ class biblioteq: public QMainWindow
   void prepareContextMenus(void);
   void prepareExternalApplicationsMenu(void);
   void prepareFilter(void);
+  void prepareIcons(void);
   void preparePhotographsPerPageMenu(void);
   void prepareRequestToolButton(const QString &typefilter);
   void prepareReservationHistoryMenu(void);
+  void prepareStatusBarIcons(void);
   void prepareTearOffMenus(void);
   void prepareUpgradeNotification(void);
-  void readConfig(void);
-  void readGlobalSetup(void);
+  void readConfigurationFile(void);
+  void readGlobalConfiguration(void);
   void resetAdminBrowser(void);
   void resetMembersBrowser(void);
 
@@ -573,6 +581,7 @@ class biblioteq: public QMainWindow
   void slotDisconnect(void);
   void slotDisplayNewSqliteDialog(void);
   void slotDuplicate(void);
+  void slotExecuteQuery(const QString &text);
   void slotExit(void);
   void slotExportAsCSV(void);
   void slotExportAsPNG(void);
@@ -664,12 +673,14 @@ class biblioteq: public QMainWindow
   void slotShowGrid(void);
   void slotShowHistory(void);
   void slotShowImport(void);
+  void slotShowMagic(void);
   void slotShowMembersBrowser(void);
   void slotShowMenu(void);
   void slotShowNext(void);
   void slotShowOtherOptions(void);
   void slotShowPassword(bool state);
   void slotShowPrev(void);
+  void slotShowQueryHistory(void);
   void slotShowReleaseNotes(void);
   void slotSpecialApplication(void);
   void slotSqliteFileSelected(bool state);
@@ -688,6 +699,8 @@ class biblioteq: public QMainWindow
   void favoritesChanged(void);
   void fontChanged(const QFont &font);
   void newFavorite(void);
+  void otherOptionsSaved(void);
+  void queryCompleted(const QString &text);
 };
 
 #endif
