@@ -26,9 +26,11 @@
 */
 
 #include <QComboBox>
+#include <QCompleter>
 #include <QFileDialog>
 #include <QProgressDialog>
 #include <QSettings>
+#include <QSqlQueryModel>
 #include <QTextStream>
 
 #include "biblioteq.h"
@@ -91,6 +93,18 @@ biblioteq_batch_activities::biblioteq_batch_activities(biblioteq *parent):
 	  SIGNAL(clicked(void)),
 	  this,
 	  SLOT(slotListMembersReservedItems(void)));
+  connect(m_ui.borrow_member_id,
+	  SIGNAL(editingFinished(void)),
+	  this,
+	  SLOT(slotDiscoverMemberName(void)));
+  connect(m_ui.borrow_member_id,
+	  SIGNAL(textEdited(const QString &)),
+	  m_ui.borrow_member_name,
+	  SLOT(clear(void)));
+  connect(m_ui.borrow_member_id,
+	  SIGNAL(textEdited(const QString &)),
+	  this,
+	  SLOT(slotBorrowerMemberIdEdited(const QString &)));
   connect(m_ui.borrow_scan,
 	  SIGNAL(returnPressed(void)),
 	  this,
@@ -123,6 +137,7 @@ biblioteq_batch_activities::biblioteq_batch_activities(biblioteq *parent):
 	  SIGNAL(returnPressed(void)),
 	  this,
 	  SLOT(slotScannedReturn(void)));
+  prepareIcons();
 }
 
 void biblioteq_batch_activities::borrow(void)
@@ -394,8 +409,48 @@ void biblioteq_batch_activities::play(const QString &file)
 #endif
 }
 
+void biblioteq_batch_activities::prepareIcons(void)
+{
+  QSettings setting;
+  auto index = setting.value("otheroptions/display_icon_set_index", 0).toInt();
+
+  if(index == 1)
+    {
+      // System.
+
+      m_ui.borrow_add_row->setIcon
+	(QIcon::fromTheme("list-add", QIcon(":/16x16/add.png")));
+      m_ui.borrow_delete_row->setIcon
+	(QIcon::fromTheme("list-remove", QIcon(":/16x16/eraser.png")));
+      m_ui.borrow_list->setIcon(QIcon(":/32x32/stamp.png"));
+      m_ui.close->setIcon
+	(QIcon::fromTheme("window-close", QIcon(":/32x32/cancel.png")));
+      m_ui.export_missing->setIcon
+	(QIcon::fromTheme("document-save-as", QIcon(":/32x32/save.png")));
+      m_ui.go->setIcon(QIcon::fromTheme("dialog-ok", QIcon(":/32x32/ok.png")));
+      m_ui.reset->setIcon
+	(QIcon::fromTheme("view-refresh", QIcon(":/32x32/reload.png")));
+    }
+  else
+    {
+      // Faenza.
+
+      m_ui.borrow_add_row->setIcon(QIcon(":/16x16/add.png"));
+      m_ui.borrow_delete_row->setIcon(QIcon(":/16x16/eraser.png"));
+      m_ui.borrow_list->setIcon(QIcon(":/32x32/stamp.png"));
+      m_ui.close->setIcon(QIcon(":/32x32/cancel.png"));
+      m_ui.export_missing->setIcon(QIcon(":/32x32/save.png"));
+      m_ui.go->setIcon(QIcon(":/32x32/ok.png"));
+      m_ui.reset->setIcon(QIcon(":/32x32/reload.png"));
+    }
+}
+
 void biblioteq_batch_activities::reset(void)
 {
+  delete findChild<QSqlQueryModel *> ("borrow_member_id_completer_model");
+  m_ui.borrow_member_id->completer() ?
+    m_ui.borrow_member_id->completer()->deleteLater() : Q_UNUSED(0);
+  m_ui.borrow_member_id->setCompleter(nullptr);
   m_ui.tab->setCurrentIndex(0);
   slotReset();
 }
@@ -886,6 +941,20 @@ void biblioteq_batch_activities::show(QMainWindow *parent, const bool center)
   activateWindow();
   raise();
   m_ui.borrow_member_id->setFocus();
+
+  if(!m_ui.borrow_member_id->completer())
+    {
+      auto completer = new QCompleter(this);
+      auto model = new QSqlQueryModel(this);
+
+      completer->setCaseSensitivity(Qt::CaseInsensitive);
+      completer->setCompletionColumn(0);
+      completer->setCompletionMode(QCompleter::InlineCompletion);
+      completer->setFilterMode(Qt::MatchContains);
+      completer->setModel(model);
+      m_ui.borrow_member_id->setCompleter(completer);
+      model->setObjectName("borrow_member_id_completer_model");
+    }
 }
 
 void biblioteq_batch_activities::slotAddBorrowingRow(void)
@@ -977,6 +1046,32 @@ void biblioteq_batch_activities::slotBorrowItemChanged(QTableWidgetItem *item)
     }
 }
 
+void biblioteq_batch_activities::slotBorrowerMemberIdEdited(const QString &text)
+{
+  auto model = findChild<QSqlQueryModel *> ("borrow_member_id_completer_model");
+
+  if(model)
+    {
+      model->clear();
+
+      if(text.trimmed().isEmpty())
+	return;
+
+      QSqlQuery query(m_qmain->getDB());
+      QString E("");
+
+      if(m_qmain->getDB().driverName() != "QSQLITE")
+	E = "E";
+
+      query.prepare
+	("SELECT memberid FROM member WHERE "
+	 "LOWER(memberid) LIKE " + E + "'%' || ? || '%'");
+      query.addBindValue(text.toLower().trimmed());
+      query.exec();
+      model->setQuery(query);
+    }
+}
+
 void biblioteq_batch_activities::slotClose(void)
 {
 #ifdef Q_OS_ANDROID
@@ -998,6 +1093,24 @@ void biblioteq_batch_activities::slotDeleteBorrowingRow(void)
   QApplication::restoreOverrideCursor();
 }
 
+void biblioteq_batch_activities::slotDiscoverMemberName(void)
+{
+  if(m_ui.borrow_member_id == sender())
+    {
+      QApplication::setOverrideCursor(Qt::WaitCursor);
+
+      QString errorstr("");
+      auto name(biblioteq_misc_functions::
+		getMemberName(m_qmain->getDB(),
+			      m_ui.borrow_member_id->text(),
+			      errorstr));
+
+      m_ui.borrow_member_name->setText(name);
+      m_ui.borrow_member_name->setCursorPosition(0);
+      QApplication::restoreOverrideCursor();
+    }
+}
+
 void biblioteq_batch_activities::slotExportMissing(void)
 {
   if(m_ui.discover_table->rowCount() == 0)
@@ -1465,6 +1578,7 @@ void biblioteq_batch_activities::slotReset(void)
 	  }
 
       m_ui.borrow_member_id->clear();
+      m_ui.borrow_member_name->clear();
       m_ui.borrow_scan->clear();
       m_ui.borrow_scan->setFocus();
       m_ui.borrow_scan_type->setCurrentIndex(0);
