@@ -30,6 +30,7 @@
 #include "biblioteq_misc_functions.h"
 
 #include <QScrollBar>
+#include <QSettings>
 
 biblioteq_borrowers_editor::biblioteq_borrowers_editor
 (QWidget *parent,
@@ -82,6 +83,7 @@ biblioteq_borrowers_editor::biblioteq_borrowers_editor
 	  this,
 	  SLOT(slotCloseCurrentBorrowers(void)));
   m_bd.table->verticalHeader()->setSectionResizeMode(QHeaderView::Fixed);
+  prepareIcons();
   setGlobalFonts(font);
   setWindowModality(Qt::ApplicationModal);
 
@@ -127,6 +129,32 @@ void biblioteq_borrowers_editor::keyPressEvent(QKeyEvent *event)
   QDialog::keyPressEvent(event);
 }
 
+void biblioteq_borrowers_editor::prepareIcons(void)
+{
+  QSettings setting;
+  auto index = setting.value("otheroptions/display_icon_set_index", 0).toInt();
+
+  if(index == 1)
+    {
+      // System.
+
+      m_bd.cancelButton->setIcon
+	(QIcon::fromTheme("window-close", QIcon(":/16x16/cancel.png")));
+      m_bd.eraseButton->setIcon
+	(QIcon::fromTheme("list-remove", QIcon(":/16x16/eraser.png")));
+      m_bd.saveButton->setIcon
+	(QIcon::fromTheme("dialog-ok", QIcon(":/16x16/ok.png")));
+    }
+  else
+    {
+      // Faenza.
+
+      m_bd.cancelButton->setIcon(QIcon(":/16x16/cancel.png"));
+      m_bd.eraseButton->setIcon(QIcon(":/16x16/eraser.png"));
+      m_bd.saveButton->setIcon(QIcon(":/16x16/ok.png"));
+    }
+}
+
 void biblioteq_borrowers_editor::setGlobalFonts(const QFont &font)
 {
   setFont(font);
@@ -143,8 +171,6 @@ void biblioteq_borrowers_editor::setGlobalFonts(const QFont &font)
 void biblioteq_borrowers_editor::showUsers(void)
 {
   QDateEdit *dateEdit = nullptr;
-  QProgressDialog progress1(this);
-  QProgressDialog progress2(this);
   QSqlQuery query(qmain->getDB());
   QString str = "";
   QStringList list;
@@ -191,12 +217,11 @@ void biblioteq_borrowers_editor::showUsers(void)
       m_columnHeaderIndexes.append("Copy Due Date");
     }
 
+  m_bd.table->horizontalScrollBar()->setValue(0);
+  m_bd.table->scrollToTop();
   m_bd.table->setColumnCount(list.size());
   m_bd.table->setHorizontalHeaderLabels(list);
-  list.clear();
   m_bd.table->setRowCount(m_quantity);
-  m_bd.table->scrollToTop();
-  m_bd.table->horizontalScrollBar()->setValue(0);
 
   /*
   ** Hide the OID column.
@@ -209,6 +234,11 @@ void biblioteq_borrowers_editor::showUsers(void)
     updateGeometry();
 
   show();
+  QApplication::processEvents();
+
+  QProgressDialog progress1(this);
+  QProgressDialog progress2(this);
+
   progress1.setLabelText(tr("Constructing objects..."));
   progress1.setMaximum(m_quantity);
   progress1.setMinimum(0);
@@ -224,12 +254,12 @@ void biblioteq_borrowers_editor::showUsers(void)
 	if(j == 6 && m_state == biblioteq::EDITABLE)
 	  {
 	    dateEdit = new QDateEdit();
-	    m_bd.table->setCellWidget(i, j, dateEdit);
 	    dateEdit->setCalendarPopup(true);
 	    dateEdit->setDate
 	      (QDate::fromString("01/01/2000",
 				 biblioteq::s_databaseDateFormat));
 	    dateEdit->setEnabled(false);
+	    m_bd.table->setCellWidget(i, j, dateEdit);
 	  }
 	else
 	  {
@@ -334,14 +364,14 @@ void biblioteq_borrowers_editor::showUsers(void)
 	  {
 	    if(j == 0)
 	      str = query.value(j).toString().trimmed();
-	    else if(j == 5 && m_state == biblioteq::EDITABLE)
+	    else if((j == 2 || j == 3) && m_state != biblioteq::EDITABLE)
 	      {
 		date = QDate::fromString
 		  (query.value(j).toString().trimmed(),
 		   biblioteq::s_databaseDateFormat);
 		str = date.toString(Qt::ISODate);
 	      }
-	    else if((j == 2 || j == 3) && m_state != biblioteq::EDITABLE)
+	    else if(j == 5 && m_state == biblioteq::EDITABLE)
 	      {
 		date = QDate::fromString
 		  (query.value(j).toString().trimmed(),
