@@ -42,26 +42,22 @@ biblioteq_cd::biblioteq_cd(biblioteq *parentArg,
 			   const QModelIndex &index):
   QMainWindow(), biblioteq_item(index)
 {
-  qmain = parentArg;
-
-  QGraphicsScene *scene1 = nullptr;
-  QGraphicsScene *scene2 = nullptr;
-  QMenu *menu = nullptr;
   QRegularExpression rx1("[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]");
-  QValidator *validator1 = nullptr;
+  auto menu = new QMenu(this);
+  auto validator1 = new QRegularExpressionValidator(rx1, this);
+  auto scene1 = new QGraphicsScene(this);
+  auto scene2 = new QGraphicsScene(this);
 
-  menu = new QMenu(this);
-  m_tracks_diag = new QDialog(this);
-  validator1 = new QRegularExpressionValidator(rx1, this);
-  scene1 = new QGraphicsScene(this);
-  scene2 = new QGraphicsScene(this);
-  m_oid = oidArg;
+  qmain = parentArg;
   m_isQueryEnabled = false;
-  m_parentWid = parentArg;
+  m_oid = oidArg;
   m_oldq = biblioteq_misc_functions::getColumnString
     (qmain->getUI().table,
      m_index->row(),
      qmain->getUI().table->columnNumber("Quantity")).toInt();
+  m_parentWid = parentArg;
+  m_tracks_diag = new QDialog(this);
+  m_tracks_diag->setWindowModality(Qt::WindowModal);
   cd.setupUi(this);
   setQMain(this);
   biblioteq_misc_functions::sortCombinationBox(cd.audio);
@@ -70,7 +66,6 @@ biblioteq_cd::biblioteq_cd(biblioteq *parentArg,
   cd.quantity->setMaximum(static_cast<int> (biblioteq::Limits::QUANTITY));
   cd.release_date->setDisplayFormat(qmain->publicationDateFormat("musiccds"));
   updateFont(QApplication::font(), qobject_cast<QWidget *> (this));
-  m_tracks_diag->setWindowModality(Qt::WindowModal);
   trd.setupUi(m_tracks_diag);
   trd.table->verticalHeader()->setSectionResizeMode(QHeaderView::Fixed);
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
@@ -83,157 +78,242 @@ biblioteq_cd::biblioteq_cd(biblioteq *parentArg,
 		SLOT(slotGo(void)));
 #endif
   updateFont(QApplication::font(), qobject_cast<QWidget *> (m_tracks_diag));
-  connect(trd.table->horizontalHeader(), SIGNAL(sectionClicked(int)),
-	  qmain, SLOT(slotResizeColumnsAfterSort(void)));
-  connect(cd.okButton, SIGNAL(clicked(void)), this, SLOT(slotGo(void)));
-  connect(cd.printButton, SIGNAL(clicked(void)), this, SLOT(slotPrint(void)));
-  connect(cd.showUserButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotShowUsers(void)));
-  connect(cd.queryButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotQuery(void)));
-  connect(cd.cancelButton, SIGNAL(clicked(void)), this,
+  connect(cd.cancelButton,
+	  SIGNAL(clicked(void)),
+	  this,
 	  SLOT(slotCancel(void)));
-  connect(cd.copiesButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotPopulateCopiesEditor(void)));
-  connect(cd.resetButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotReset(void)));
-  connect(cd.tracksButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotPopulateTracksBrowser(void)));
-  connect(trd.cancelButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotCloseTracksBrowser(void)));
-  connect(trd.insertButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotInsertTrack(void)));
-  connect(trd.deleteButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotDeleteTrack(void)));
-  connect(trd.saveButton, SIGNAL(clicked(void)), this,
-	  SLOT(slotSaveTracks(void)));
-  connect(cd.computeButton, SIGNAL(clicked(void)), this,
+  connect(cd.computeButton,
+	  SIGNAL(clicked(void)),
+	  this,
 	  SLOT(slotComputeRuntime(void)));
+  connect(cd.copiesButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotPopulateCopiesEditor(void)));
+  connect(cd.okButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotGo(void)));
+  connect(cd.printButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotPrint(void)));
+  connect(cd.queryButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotQuery(void)));
+  connect(cd.resetButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotReset(void)));
+  connect(cd.showUserButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotShowUsers(void)));
+  connect(cd.tracksButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotPopulateTracksBrowser(void)));
+  connect(trd.cancelButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotCloseTracksBrowser(void)));
+  connect(trd.deleteButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotDeleteTrack(void)));
+  connect(trd.insertButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotInsertTrack(void)));
+  connect(trd.saveButton,
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotSaveTracks(void)));
+  connect(trd.table->horizontalHeader(),
+	  SIGNAL(sectionClicked(int)),
+	  qmain,
+	  SLOT(slotResizeColumnsAfterSort(void)));
   connect(menu->addAction(tr("Reset Front Cover Image")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Back Cover Image")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Catalog Number")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Format")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Artist")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   m_composer_action = menu->addAction(tr("Reset Composer"));
-  connect(m_composer_action, SIGNAL(triggered(void)),
-	  this, SLOT(slotReset(void)));
   m_composer_action->setVisible(false);
+  connect(m_composer_action,
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Number of Discs")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Runtime")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Audio")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Recording Type")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Title")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Release Date")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Recording Label")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Categories")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Price")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Language")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Monetary Units")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Copies")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Location")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Abstract")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Keywords")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(menu->addAction(tr("Reset Accession Number")),
-	  SIGNAL(triggered(void)), this, SLOT(slotReset(void)));
+	  SIGNAL(triggered(void)),
+	  this,
+	  SLOT(slotReset(void)));
   connect(cd.frontButton,
-	  SIGNAL(clicked(void)), this, SLOT(slotSelectImage(void)));
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotSelectImage(void)));
   connect(cd.backButton,
-	  SIGNAL(clicked(void)), this, SLOT(slotSelectImage(void)));
+	  SIGNAL(clicked(void)),
+	  this,
+	  SLOT(slotSelectImage(void)));
   connect(qmain,
 	  SIGNAL(fontChanged(const QFont &)),
 	  this,
 	  SLOT(setGlobalFonts(const QFont &)));
-  cd.queryButton->setVisible(m_isQueryEnabled);
-  cd.resetButton->setMenu(menu);
-  cd.id->setValidator(validator1);
+  connect(qmain,
+	  SIGNAL(otherOptionsSaved(void)),
+	  this,
+	  SLOT(slotPrepareIcons(void)));
   cd.composer->setVisible(false);
   cd.composer_label->setVisible(false);
+  cd.id->setValidator(validator1);
+  cd.queryButton->setVisible(m_isQueryEnabled);
+  cd.resetButton->setMenu(menu);
 
   QString errorstr("");
 
   QApplication::setOverrideCursor(Qt::WaitCursor);
   cd.language->addItems
-    (biblioteq_misc_functions::getLanguages(qmain->getDB(),
-					    errorstr));
+    (biblioteq_misc_functions::getLanguages(qmain->getDB(), errorstr));
   QApplication::restoreOverrideCursor();
 
   if(!errorstr.isEmpty())
     qmain->addError
       (QString(tr("Database Error")),
        QString(tr("Unable to retrieve the languages.")),
-       errorstr, __FILE__, __LINE__);
+       errorstr,
+       __FILE__,
+       __LINE__);
 
   QApplication::setOverrideCursor(Qt::WaitCursor);
   cd.monetary_units->addItems
-    (biblioteq_misc_functions::getMonetaryUnits(qmain->getDB(),
-						errorstr));
+    (biblioteq_misc_functions::getMonetaryUnits(qmain->getDB(), errorstr));
   QApplication::restoreOverrideCursor();
 
   if(!errorstr.isEmpty())
     qmain->addError
       (QString(tr("Database Error")),
        QString(tr("Unable to retrieve the monetary units.")),
-       errorstr, __FILE__, __LINE__);
+       errorstr,
+       __FILE__,
+       __LINE__);
 
   QApplication::setOverrideCursor(Qt::WaitCursor);
   cd.location->addItems
-    (biblioteq_misc_functions::getLocations(qmain->getDB(),
-					    "CD",
-					    errorstr));
+    (biblioteq_misc_functions::getLocations(qmain->getDB(), "CD", errorstr));
   QApplication::restoreOverrideCursor();
 
   if(!errorstr.isEmpty())
     qmain->addError
       (QString(tr("Database Error")),
        QString(tr("Unable to retrieve the cd locations.")),
-       errorstr, __FILE__, __LINE__);
+       errorstr,
+       __FILE__,
+       __LINE__);
 
   QApplication::setOverrideCursor(Qt::WaitCursor);
   cd.format->addItems
-    (biblioteq_misc_functions::getCDFormats(qmain->getDB(),
-					    errorstr));
+    (biblioteq_misc_functions::getCDFormats(qmain->getDB(), errorstr));
   QApplication::restoreOverrideCursor();
 
   if(!errorstr.isEmpty())
     qmain->addError
       (QString(tr("Database Error")),
        QString(tr("Unable to retrieve the cd formats.")),
-       errorstr, __FILE__, __LINE__);
+       errorstr,
+       __FILE__,
+       __LINE__);
 
-  cd.front_image->setScene(scene1);
   cd.back_image->setScene(scene2);
+  cd.front_image->setScene(scene1);
+
+  if(cd.format->findText(biblioteq::s_unknown) == -1)
+    cd.format->addItem(biblioteq::s_unknown);
 
   if(cd.language->findText(biblioteq::s_unknown) == -1)
     cd.language->addItem(biblioteq::s_unknown);
 
-  if(cd.monetary_units->findText(biblioteq::s_unknown) == -1)
-    cd.monetary_units->addItem(biblioteq::s_unknown);
-
   if(cd.location->findText(biblioteq::s_unknown) == -1)
     cd.location->addItem(biblioteq::s_unknown);
 
-  if(cd.format->findText(biblioteq::s_unknown) == -1)
-    cd.format->addItem(biblioteq::s_unknown);
+  if(cd.monetary_units->findText(biblioteq::s_unknown) == -1)
+    cd.monetary_units->addItem(biblioteq::s_unknown);
 
 #ifndef Q_OS_ANDROID
   if(m_parentWid)
@@ -290,9 +370,10 @@ void biblioteq_cd::closeEvent(QCloseEvent *e)
     if(hasDataChanged(this))
       {
 	if(QMessageBox::
-	   question(this, tr("BiblioteQ: Question"),
+	   question(this,
+		    tr("BiblioteQ: Question"),
 		    tr("Your changes have not been saved. Continue closing?"),
-		    QMessageBox::Yes | QMessageBox::No,
+		    QMessageBox::No | QMessageBox::Yes,
 		    QMessageBox::No) == QMessageBox::No)
 	  {
 	    QApplication::processEvents();
@@ -323,52 +404,52 @@ void biblioteq_cd::duplicate(const QString &p_oid, const int state)
 void biblioteq_cd::insert(void)
 {
   slotReset();
-  cd.id->clear();
+  cd.accession_number->clear();
   cd.artist->setPlainText("N/A");
-  cd.title->clear();
-  cd.recording_label->setPlainText("N/A");
-  cd.description->setPlainText("N/A");
-  cd.keyword->clear();
+  cd.audio->setCurrentIndex(0);
   cd.category->setPlainText("N/A");
-  cd.copiesButton->setEnabled(false);
-  cd.tracksButton->setEnabled(false);
-  cd.showUserButton->setEnabled(false);
-  cd.queryButton->setEnabled(true);
   cd.computeButton->setVisible(true);
+  cd.copiesButton->setEnabled(false);
+  cd.description->setPlainText("N/A");
+  cd.format->setCurrentIndex(0);
+  cd.id->clear();
+  cd.keyword->clear();
+  cd.language->setCurrentIndex(0);
+  cd.location->setCurrentIndex(0);
+  cd.monetary_units->setCurrentIndex(0);
+  cd.no_of_discs->setMinimum(1);
+  cd.no_of_discs->setValue(1);
   cd.okButton->setText(tr("&Save"));
-  cd.release_date->setDate(QDate::fromString("01/01/2000",
-					     biblioteq::s_databaseDateFormat));
-  cd.runtime->setTime(QTime(0, 0, 1));
-  cd.runtime->setMinimumTime(QTime(0, 0, 1));
   cd.price->setMinimum(0.00);
   cd.price->setValue(0.00);
   cd.quantity->setMinimum(1);
   cd.quantity->setValue(1);
-  cd.no_of_discs->setMinimum(1);
-  cd.no_of_discs->setValue(1);
-  cd.audio->setCurrentIndex(0);
-  cd.location->setCurrentIndex(0);
-  cd.language->setCurrentIndex(0);
-  cd.monetary_units->setCurrentIndex(0);
+  cd.queryButton->setEnabled(true);
+  cd.recording_label->setPlainText("N/A");
   cd.recording_type->setCurrentIndex(0);
-  cd.format->setCurrentIndex(0);
-  cd.accession_number->clear();
-  biblioteq_misc_functions::highlightWidget
-    (cd.id, m_requiredHighlightColor);
-  biblioteq_misc_functions::highlightWidget
-    (cd.title, m_requiredHighlightColor);
-  biblioteq_misc_functions::highlightWidget
-    (cd.recording_label->viewport(), m_requiredHighlightColor);
+  cd.release_date->setDate
+    (QDate::fromString("01/01/2000", biblioteq::s_databaseDateFormat));
+  cd.runtime->setMinimumTime(QTime(0, 0, 1));
+  cd.runtime->setTime(QTime(0, 0, 1));
+  cd.showUserButton->setEnabled(false);
+  cd.title->clear();
+  cd.tracksButton->setEnabled(false);
   biblioteq_misc_functions::highlightWidget
     (cd.artist->viewport(), m_requiredHighlightColor);
+  biblioteq_misc_functions::highlightWidget
+    (cd.category->viewport(), m_requiredHighlightColor);
   biblioteq_misc_functions::highlightWidget
     (cd.description->viewport(), m_requiredHighlightColor);
   biblioteq_misc_functions::highlightWidget
-    (cd.category->viewport(), m_requiredHighlightColor);
-  setWindowTitle(tr("BiblioteQ: Create Music CD Entry"));
-  m_engWindowTitle = "Create";
+    (cd.id, m_requiredHighlightColor);
+  biblioteq_misc_functions::highlightWidget
+    (cd.recording_label->viewport(), m_requiredHighlightColor);
+  biblioteq_misc_functions::highlightWidget
+    (cd.title, m_requiredHighlightColor);
   cd.id->setFocus();
+  m_engWindowTitle = "Create";
   prepareFavorites();
+  setWindowTitle(tr("BiblioteQ: Create Music CD Entry"));
   storeData(this);
 #ifdef Q_OS_ANDROID
   showMaximized();
@@ -378,6 +459,7 @@ void biblioteq_cd::insert(void)
 #endif
   activateWindow();
   raise();
+  prepareIcons(this);
 }
 
 void biblioteq_cd::modify(const int state)
@@ -446,8 +528,6 @@ void biblioteq_cd::modify(const int state)
 	  actions[0]->setVisible(false);
 	  actions[1]->setVisible(false);
 	}
-
-      actions.clear();
     }
 
   cd.tracksButton->setEnabled(true);
@@ -459,6 +539,7 @@ void biblioteq_cd::modify(const int state)
   cd.quantity->setValue(1);
   cd.no_of_discs->setMinimum(1);
   cd.no_of_discs->setValue(1);
+  prepareIcons(this);
   str = m_oid;
   query.prepare("SELECT id, "
 		"title, "
@@ -493,10 +574,12 @@ void biblioteq_cd::modify(const int state)
       qmain->addError
 	(QString(tr("Database Error")),
 	 QString(tr("Unable to retrieve the selected CD's data.")),
-	 query.lastError().text(), __FILE__, __LINE__);
-      QMessageBox::critical(this, tr("BiblioteQ: Database Error"),
-			    tr("Unable to retrieve the selected CD's "
-			       "data."));
+	 query.lastError().text(),
+	 __FILE__,
+	 __LINE__);
+      QMessageBox::critical(this,
+			    tr("BiblioteQ: Database Error"),
+			    tr("Unable to retrieve the selected CD's data."));
       QApplication::processEvents();
       close();
       return;
@@ -665,56 +748,68 @@ void biblioteq_cd::prepareFavorites(void)
   cd.format->setCurrentIndex
     (cd.format->findText(settings.value("cd_formats_favorite").
 			 toString().trimmed()));
+  cd.language->setCurrentIndex
+    (cd.language->
+     findText(settings.value("languages_favorite").toString().trimmed()));
+  cd.monetary_units->setCurrentIndex
+    (cd.monetary_units->
+     findText(settings.value("monetary_units_favorite").toString().trimmed()));
 
   if(cd.format->currentIndex() < 0)
     cd.format->setCurrentIndex(0);
+
+  if(cd.language->currentIndex() < 0)
+    cd.language->setCurrentIndex(0);
+
+  if(cd.monetary_units->currentIndex() < 0)
+    cd.monetary_units->setCurrentIndex(0);
 }
 
 void biblioteq_cd::search(const QString &field, const QString &value)
 {
-  m_composer_action->setVisible(true);
+  cd.accession_number->clear();
+  cd.artist->clear();
+  cd.audio->insertItem(0, tr("Any"));
+  cd.audio->setCurrentIndex(0);
+  cd.category->clear();
   cd.composer->setVisible(true);
   cd.composer_label->setVisible(true);
-  cd.id->clear();
-  cd.artist->clear();
-  cd.title->clear();
-  cd.recording_label->clear();
-  cd.description->clear();
-  cd.keyword->clear();
-  cd.category->clear();
-  cd.copiesButton->setVisible(false);
-  cd.tracksButton->setVisible(false);
-  cd.queryButton->setVisible(false);
-  cd.showUserButton->setVisible(false);
   cd.computeButton->setVisible(false);
-  cd.tracks_lbl->setVisible(false);
-  cd.okButton->setText(tr("&Search"));
-  cd.publication_date_enabled->setVisible(true);
-  cd.release_date->setDate(QDate::fromString("2001", "yyyy"));
-  cd.release_date->setDisplayFormat("yyyy");
-  cd.runtime->setTime(QTime(0, 0, 0));
-  cd.runtime->setMinimumTime(QTime(0, 0, 0));
-  cd.price->setMinimum(-0.01);
-  cd.price->setValue(-0.01);
-  cd.quantity->setMinimum(0);
-  cd.quantity->setValue(0);
+  cd.copiesButton->setVisible(false);
+  cd.description->clear();
+  cd.format->insertItem(0, tr("Any"));
+  cd.format->setCurrentIndex(0);
+  cd.id->clear();
+  cd.keyword->clear();
+  cd.language->insertItem(0, tr("Any"));
+  cd.language->setCurrentIndex(0);
+  cd.location->insertItem(0, tr("Any"));
+  cd.location->setCurrentIndex(0);
+  cd.monetary_units->insertItem(0, tr("Any"));
+  cd.monetary_units->setCurrentIndex(0);
   cd.no_of_discs->setMinimum(0);
   cd.no_of_discs->setValue(0);
-  cd.audio->insertItem(0, tr("Any"));
+  cd.okButton->setText(tr("&Search"));
+  cd.price->setMinimum(-0.01);
+  cd.price->setValue(-0.01);
+  cd.publication_date_enabled->setVisible(true);
+  cd.quantity->setMinimum(0);
+  cd.quantity->setValue(0);
+  cd.queryButton->setVisible(false);
+  cd.recording_label->clear();
   cd.recording_type->insertItem(0, tr("Any"));
-  cd.format->insertItem(0, tr("Any"));
-  cd.language->insertItem(0, tr("Any"));
-  cd.monetary_units->insertItem(0, tr("Any"));
-  cd.location->insertItem(0, tr("Any"));
-  cd.audio->setCurrentIndex(0);
-  cd.location->setCurrentIndex(0);
-  cd.language->setCurrentIndex(0);
-  cd.monetary_units->setCurrentIndex(0);
   cd.recording_type->setCurrentIndex(0);
-  cd.format->setCurrentIndex(0);
-  cd.accession_number->clear();
+  cd.release_date->setDate(QDate::fromString("2001", "yyyy"));
+  cd.release_date->setDisplayFormat("yyyy");
+  cd.runtime->setMinimumTime(QTime(0, 0, 0));
+  cd.runtime->setTime(QTime(0, 0, 0));
+  cd.showUserButton->setVisible(false);
+  cd.title->clear();
+  cd.tracksButton->setVisible(false);
+  cd.tracks_lbl->setVisible(false);
+  m_composer_action->setVisible(true);
   m_engWindowTitle = "Search";
-  prepareFavorites();
+  prepareIcons(this);
 
   if(field.isEmpty() && value.isEmpty())
     {
@@ -726,10 +821,10 @@ void biblioteq_cd::search(const QString &field, const QString &value)
 	  actions[1]->setVisible(false);
 	}
 
-      actions.clear();
       cd.coverImages->setVisible(false);
-      setWindowTitle(tr("BiblioteQ: Database Music CD Search"));
       cd.id->setFocus();
+      prepareFavorites();
+      setWindowTitle(tr("BiblioteQ: Database Music CD Search"));
 #ifdef Q_OS_ANDROID
       showMaximized();
 #else
@@ -743,12 +838,12 @@ void biblioteq_cd::search(const QString &field, const QString &value)
     {
       if(field == "artist")
 	cd.artist->setPlainText(value);
-      else if(field == "recording_label")
-	cd.recording_label->setPlainText(value);
       else if(field == "category")
 	cd.category->setPlainText(value);
       else if(field == "keyword")
 	cd.keyword->setPlainText(value);
+      else if(field == "recording_label")
+	cd.recording_label->setPlainText(value);
 
       slotGo();
     }
@@ -858,9 +953,12 @@ void biblioteq_cd::slotGo(void)
 		(QString(tr("Database Error")),
 		 QString(tr("Unable to determine the maximum copy number of "
 			    "the item.")),
-		 errorstr, __FILE__, __LINE__);
+		 errorstr,
+		 __FILE__,
+		 __LINE__);
 	      QMessageBox::critical
-		(this, tr("BiblioteQ: Database Error"),
+		(this,
+		 tr("BiblioteQ: Database Error"),
 		 tr("Unable to determine the maximum copy number of "
 		    "the item."));
 	      QApplication::processEvents();
@@ -872,7 +970,8 @@ void biblioteq_cd::slotGo(void)
 	  if(newq < maxcopynumber)
 	    {
 	      QMessageBox::critical
-		(this, tr("BiblioteQ: User Error"),
+		(this,
+		 tr("BiblioteQ: User Error"),
 		 tr("It appears that you are attempting to decrease the "
 		    "number of copies while there are copies "
 		    "that have been reserved."));
@@ -883,10 +982,11 @@ void biblioteq_cd::slotGo(void)
 	  else if(newq > m_oldq)
 	    {
 	      if(QMessageBox::question
-		 (this, tr("BiblioteQ: Question"),
+		 (this,
+		  tr("BiblioteQ: Question"),
 		  tr("You have increased the number of copies. "
 		     "Would you like to modify copy information?"),
-		  QMessageBox::Yes | QMessageBox::No,
+		  QMessageBox::No | QMessageBox::Yes,
 		  QMessageBox::No) == QMessageBox::Yes)
 		{
 		  QApplication::processEvents();
@@ -903,7 +1003,8 @@ void biblioteq_cd::slotGo(void)
       if(cd.id->text().isEmpty())
 	{
 	  QMessageBox::critical
-	    (this, tr("BiblioteQ: User Error"),
+	    (this,
+	     tr("BiblioteQ: User Error"),
 	     tr("Please complete the Catalog Number field."));
 	  QApplication::processEvents();
 	  cd.id->setFocus();
@@ -915,7 +1016,8 @@ void biblioteq_cd::slotGo(void)
 
       if(cd.artist->toPlainText().isEmpty())
 	{
-	  QMessageBox::critical(this, tr("BiblioteQ: User Error"),
+	  QMessageBox::critical(this,
+				tr("BiblioteQ: User Error"),
 				tr("Please complete the Artist field."));
 	  QApplication::processEvents();
 	  cd.artist->setFocus();
@@ -924,7 +1026,8 @@ void biblioteq_cd::slotGo(void)
 
       if(cd.runtime->text() == "00:00:00")
 	{
-	  QMessageBox::critical(this, tr("BiblioteQ: User Error"),
+	  QMessageBox::critical(this,
+				tr("BiblioteQ: User Error"),
 				tr("Please provide a valid Runtime."));
 	  QApplication::processEvents();
 	  cd.runtime->setFocus();
@@ -936,7 +1039,8 @@ void biblioteq_cd::slotGo(void)
 
       if(cd.title->text().isEmpty())
 	{
-	  QMessageBox::critical(this, tr("BiblioteQ: User Error"),
+	  QMessageBox::critical(this,
+				tr("BiblioteQ: User Error"),
 				tr("Please complete the Title field."));
 	  QApplication::processEvents();
 	  cd.title->setFocus();
@@ -948,9 +1052,10 @@ void biblioteq_cd::slotGo(void)
 
       if(cd.recording_label->toPlainText().isEmpty())
 	{
-	  QMessageBox::critical(this, tr("BiblioteQ: User Error"),
-				tr("Please complete the Recording Label "
-				   "field."));
+	  QMessageBox::
+	    critical(this,
+		     tr("BiblioteQ: User Error"),
+		     tr("Please complete the Recording Label field."));
 	  QApplication::processEvents();
 	  cd.recording_label->setFocus();
 	  return;
@@ -961,9 +1066,9 @@ void biblioteq_cd::slotGo(void)
 
       if(cd.category->toPlainText().isEmpty())
 	{
-	  QMessageBox::critical(this, tr("BiblioteQ: User Error"),
-				tr("Please complete the Categories "
-				   "field."));
+	  QMessageBox::critical(this,
+				tr("BiblioteQ: User Error"),
+				tr("Please complete the Categories field."));
 	  QApplication::processEvents();
 	  cd.category->setFocus();
 	  return;
@@ -974,7 +1079,8 @@ void biblioteq_cd::slotGo(void)
 
       if(cd.description->toPlainText().isEmpty())
 	{
-	  QMessageBox::critical(this, tr("BiblioteQ: User Error"),
+	  QMessageBox::critical(this,
+				tr("BiblioteQ: User Error"),
 				tr("Please complete the Abstract field."));
 	  QApplication::processEvents();
 	  cd.description->setFocus();
@@ -989,9 +1095,12 @@ void biblioteq_cd::slotGo(void)
 	  qmain->addError
 	    (QString(tr("Database Error")),
 	     QString(tr("Unable to create a database transaction.")),
-	     qmain->getDB().lastError().text(), __FILE__, __LINE__);
+	     qmain->getDB().lastError().text(),
+	     __FILE__,
+	     __LINE__);
 	  QMessageBox::critical
-	    (this, tr("BiblioteQ: Database Error"),
+	    (this,
+	     tr("BiblioteQ: Database Error"),
 	     tr("Unable to create a database transaction."));
 	  QApplication::processEvents();
 	  return;
@@ -1177,8 +1286,7 @@ void biblioteq_cd::slotGo(void)
 	    query.bindValue(21, value);
 	  else
 	    qmain->addError(QString(tr("Database Error")),
-			    QString(tr("Unable to generate a unique "
-				       "integer.")),
+			    QString(tr("Unable to generate a unique integer.")),
 			    errorstr);
 	}
 
@@ -1190,7 +1298,9 @@ void biblioteq_cd::slotGo(void)
 	  qmain->addError
 	    (QString(tr("Database Error")),
 	     QString(tr("Unable to create or update the entry.")),
-	     query.lastError().text(), __FILE__, __LINE__);
+	     query.lastError().text(),
+	     __FILE__,
+	     __LINE__);
 	  goto db_rollback;
 	}
       else
@@ -1219,9 +1329,10 @@ void biblioteq_cd::slotGo(void)
 		  QApplication::restoreOverrideCursor();
 		  qmain->addError
 		    (QString(tr("Database Error")),
-		     QString(tr("Unable to purge unnecessary copy "
-				"data.")),
-		     query.lastError().text(), __FILE__, __LINE__);
+		     QString(tr("Unable to purge unnecessary copy data.")),
+		     query.lastError().text(),
+		     __FILE__,
+		     __LINE__);
 		  goto db_rollback;
 		}
 
@@ -1232,7 +1343,8 @@ void biblioteq_cd::slotGo(void)
 		    (QString(tr("Database Error")),
 		     QString(tr("Unable to commit the current database "
 				"transaction.")),
-		     qmain->getDB().lastError().text(), __FILE__,
+		     qmain->getDB().lastError().text(),
+		     __FILE__,
 		     __LINE__);
 		  goto db_rollback;
 		}
@@ -1255,7 +1367,9 @@ void biblioteq_cd::slotGo(void)
 		  qmain->addError
 		    (QString(tr("Database Error")),
 		     QString(tr("Unable to create initial copies.")),
-		     errorstr, __FILE__, __LINE__);
+		     errorstr,
+		     __FILE__,
+		     __LINE__);
 		  goto db_rollback;
 		}
 
@@ -1266,7 +1380,8 @@ void biblioteq_cd::slotGo(void)
 		    (QString(tr("Database Error")),
 		     QString(tr("Unable to commit the current database "
 				"transaction.")),
-		     qmain->getDB().lastError().text(), __FILE__,
+		     qmain->getDB().lastError().text(),
+		     __FILE__,
 		     __LINE__);
 		  goto db_rollback;
 		}
@@ -1397,7 +1512,9 @@ void biblioteq_cd::slotGo(void)
 			    qmain->addError
 			      (QString(tr("Database Error")),
 			       QString(tr("Retrieving availability.")),
-			       errorstr, __FILE__, __LINE__);
+			       errorstr,
+			       __FILE__,
+			       __LINE__);
 			}
 		      else if(names.at(i) == "Accession Number")
 			qmain->getUI().table->item(m_index->row(), i)->setText
@@ -1427,13 +1544,16 @@ void biblioteq_cd::slotGo(void)
 
 	      if(!errorstr.isEmpty())
 		{
-		  qmain->addError(QString(tr("Database Error")),
-				  QString(tr("Unable to retrieve the CD's "
-					     "OID.")),
-				  errorstr, __FILE__, __LINE__);
-		  QMessageBox::critical(this, tr("BiblioteQ: Database Error"),
-					tr("Unable to retrieve the CD's "
-					   "OID."));
+		  qmain->addError
+		    (QString(tr("Database Error")),
+		     QString(tr("Unable to retrieve the CD's OID.")),
+		     errorstr,
+		     __FILE__,
+		     __LINE__);
+		  QMessageBox::critical
+		    (this,
+		     tr("BiblioteQ: Database Error"),
+		     tr("Unable to retrieve the CD's OID."));
 		  QApplication::processEvents();
 		}
 	      else
@@ -1462,14 +1582,18 @@ void biblioteq_cd::slotGo(void)
 
       if(!qmain->getDB().rollback())
 	qmain->addError
-	  (QString(tr("Database Error")), QString(tr("Rollback failure.")),
-	   qmain->getDB().lastError().text(), __FILE__, __LINE__);
+	  (QString(tr("Database Error")),
+	   QString(tr("Rollback failure.")),
+	   qmain->getDB().lastError().text(),
+	   __FILE__,
+	   __LINE__);
 
       QApplication::restoreOverrideCursor();
-      QMessageBox::critical(this, tr("BiblioteQ: Database Error"),
-			    tr("Unable to create or update the entry. "
-			       "Please verify that "
-			       "the entry does not already exist."));
+      QMessageBox::critical
+	(this,
+	 tr("BiblioteQ: Database Error"),
+	 tr("Unable to create or update the entry. Please verify that "
+	    "the entry does not already exist."));
       QApplication::processEvents();
     }
   else if(m_engWindowTitle.contains("Search"))
@@ -1744,7 +1868,6 @@ void biblioteq_cd::slotInsertTrack(void)
 	}
     }
 
-  list.clear();
   trd.table->setSortingEnabled(false);
 
   for(int i = 0; i < trd.table->columnCount() - 1; i++)
@@ -1755,9 +1878,7 @@ void biblioteq_cd::slotInsertTrack(void)
 
 void biblioteq_cd::slotPopulateCopiesEditor(void)
 {
-  biblioteq_copy_editor *copyeditor = nullptr;
-
-  copyeditor = new biblioteq_copy_editor
+  auto copyeditor = new biblioteq_copy_editor
     (qobject_cast<QWidget *> (this),
      qmain,
      static_cast<biblioteq_item *> (this),
@@ -1769,6 +1890,7 @@ void biblioteq_cd::slotPopulateCopiesEditor(void)
      "CD",
      cd.id->text().trimmed(),
      false);
+
   copyeditor->populateCopiesEditor();
 }
 
@@ -1801,10 +1923,12 @@ void biblioteq_cd::slotPopulateTracksBrowser(void)
 		      QString(tr("Unable to retrieve track data for table "
 				 "populating.")),
 		      query.lastError().text(),
-		      __FILE__, __LINE__);
-      QMessageBox::critical(this, tr("BiblioteQ: Database Error"),
-			    tr("Unable to retrieve track data for "
-			       "table populating."));
+		      __FILE__,
+		      __LINE__);
+      QMessageBox::critical
+	(this,
+	 tr("BiblioteQ: Database Error"),
+	 tr("Unable to retrieve track data for table populating."));
       QApplication::processEvents();
       return;
     }
@@ -1825,7 +1949,6 @@ void biblioteq_cd::slotPopulateTracksBrowser(void)
   list.append(tr("Composer"));
   trd.table->setColumnCount(list.size());
   trd.table->setHorizontalHeaderLabels(list);
-  list.clear();
   trd.table->setRowCount(0);
   trd.table->scrollToTop();
   trd.table->horizontalScrollBar()->setValue(0);
@@ -1935,7 +2058,6 @@ void biblioteq_cd::slotPopulateTracksBrowser(void)
 
   progress.close();
   trd.table->setSortingEnabled(false);
-  comboBoxList.clear();
   trd.table->setRowCount(i); // Support cancellation.
 
   for(int i = 0; i < trd.table->columnCount() - 1; i++)
@@ -1944,6 +2066,11 @@ void biblioteq_cd::slotPopulateTracksBrowser(void)
   trd.table->resizeRowsToContents();
 }
 
+void biblioteq_cd::slotPrepareIcons(void)
+{
+  prepareIcons(this);
+}
+
 void biblioteq_cd::slotPrint(void)
 {
   m_html = "<html>";
@@ -2146,8 +2273,6 @@ void biblioteq_cd::slotReset(void)
 	  cd.accession_number->clear();
 	  cd.accession_number->setFocus();
 	}
-
-      actions.clear();
     }
   else
     {
@@ -2224,7 +2349,8 @@ void biblioteq_cd::slotSaveTracks(void)
       {
 	errormsg = QString(tr("Row number ")) + QString::number(i + 1) +
 	  tr(" contains an empty Song Title.");
-	QMessageBox::critical(m_tracks_diag, tr("BiblioteQ: User Error"),
+	QMessageBox::critical(m_tracks_diag,
+			      tr("BiblioteQ: User Error"),
 			      errormsg);
 	QApplication::processEvents();
 	return;
@@ -2237,8 +2363,11 @@ void biblioteq_cd::slotSaveTracks(void)
       QApplication::restoreOverrideCursor();
       qmain->addError(QString(tr("Database Error")),
 		      QString(tr("Unable to create a database transaction.")),
-		      qmain->getDB().lastError().text(), __FILE__, __LINE__);
-      QMessageBox::critical(m_tracks_diag, tr("BiblioteQ: Database Error"),
+		      qmain->getDB().lastError().text(),
+		      __FILE__,
+		      __LINE__);
+      QMessageBox::critical(m_tracks_diag,
+			    tr("BiblioteQ: Database Error"),
 			    tr("Unable to create a database transaction."));
       QApplication::processEvents();
       return;
@@ -2254,14 +2383,17 @@ void biblioteq_cd::slotSaveTracks(void)
       QApplication::restoreOverrideCursor();
       qmain->addError(QString(tr("Database Error")),
 		      QString(tr("Unable to purge track data.")),
-		      query.lastError().text(), __FILE__, __LINE__);
+		      query.lastError().text(),
+		      __FILE__,
+		      __LINE__);
       QApplication::setOverrideCursor(Qt::WaitCursor);
 
       if(!qmain->getDB().rollback())
 	qmain->addError(QString(tr("Database Error")),
 			QString(tr("Rollback failure.")),
 			qmain->getDB().lastError().text(),
-			__FILE__, __LINE__);
+			__FILE__,
+			__LINE__);
 
       QApplication::restoreOverrideCursor();
     }
@@ -2332,7 +2464,9 @@ void biblioteq_cd::slotSaveTracks(void)
 	    {
 	      qmain->addError(QString(tr("Database Error")),
 			      QString(tr("Unable to create track data.")),
-			      query.lastError().text(), __FILE__, __LINE__);
+			      query.lastError().text(),
+			      __FILE__,
+			      __LINE__);
 	      lastError = query.lastError().text();
 	    }
 
@@ -2350,7 +2484,8 @@ void biblioteq_cd::slotSaveTracks(void)
 	{
 	  qmain->addError(QString(tr("Database Error")),
 			  QString(tr("Commit failure.")),
-			  qmain->getDB().lastError().text(), __FILE__,
+			  qmain->getDB().lastError().text(),
+			  __FILE__,
 			  __LINE__);
 	  qmain->getDB().rollback();
 	}
@@ -2360,9 +2495,10 @@ void biblioteq_cd::slotSaveTracks(void)
       if(!lastError.isEmpty() ||
 	 qmain->getDB().lastError().isValid())
 	{
-	  QMessageBox::critical(m_tracks_diag, tr("BiblioteQ: Database Error"),
-				tr("Some or all of the track data has not "
-				   "been saved."));
+	  QMessageBox::critical
+	    (m_tracks_diag,
+	     tr("BiblioteQ: Database Error"),
+	     tr("Some or all of the track data has not been saved."));
 	  QApplication::processEvents();
 	}
 
@@ -2370,8 +2506,7 @@ void biblioteq_cd::slotSaveTracks(void)
       ** Update the runtime.
       */
 
-      if(lastError.isEmpty() &&
-	 !qmain->getDB().lastError().isValid())
+      if(lastError.isEmpty() && !qmain->getDB().lastError().isValid())
 	slotComputeRuntime();
     }
 }
@@ -2440,7 +2575,6 @@ void biblioteq_cd::slotSelectImage(void)
 
 void biblioteq_cd::slotShowUsers(void)
 {
-  biblioteq_borrowers_editor *borrowerseditor = nullptr;
   int state = 0;
 
   if(!cd.okButton->isHidden())
@@ -2448,7 +2582,7 @@ void biblioteq_cd::slotShowUsers(void)
   else
     state = biblioteq::VIEW_ONLY;
 
-  borrowerseditor = new biblioteq_borrowers_editor
+  auto borrowerseditor = new biblioteq_borrowers_editor
     (qobject_cast<QWidget *> (this),
      qmain,
      static_cast<biblioteq_item *> (this),
@@ -2458,6 +2592,7 @@ void biblioteq_cd::slotShowUsers(void)
      font(),
      "CD",
      state);
+
   borrowerseditor->showUsers();
 }
 
@@ -2467,44 +2602,47 @@ void biblioteq_cd::updateWindow(const int state)
 
   if(state == biblioteq::EDITABLE)
     {
-      cd.showUserButton->setEnabled(true);
+      cd.backButton->setVisible(true);
+      cd.computeButton->setVisible(true);
       cd.copiesButton->setEnabled(true);
+      cd.frontButton->setVisible(true);
       cd.okButton->setVisible(true);
       cd.queryButton->setVisible(m_isQueryEnabled);
       cd.resetButton->setVisible(true);
-      cd.computeButton->setVisible(true);
-      trd.saveButton->setVisible(true);
-      trd.insertButton->setVisible(true);
+      cd.showUserButton->setEnabled(true);
       trd.deleteButton->setVisible(true);
-      cd.frontButton->setVisible(true);
-      cd.backButton->setVisible(true);
+      trd.insertButton->setVisible(true);
+      trd.saveButton->setVisible(true);
       str = QString(tr("BiblioteQ: Modify Music CD Entry (")) +
-	cd.id->text() + tr(")");
+	cd.id->text() +
+	tr(")");
       m_engWindowTitle = "Modify";
     }
   else
     {
+      cd.backButton->setVisible(false);
+      cd.computeButton->setVisible(false);
+      cd.copiesButton->setVisible(false);
+      cd.frontButton->setVisible(false);
+      cd.okButton->setVisible(false);
+      cd.queryButton->setVisible(false);
+      cd.resetButton->setVisible(false);
+
       if(qmain->isGuest())
 	cd.showUserButton->setVisible(false);
       else
 	cd.showUserButton->setEnabled(true);
 
-      cd.copiesButton->setVisible(false);
-      cd.okButton->setVisible(false);
-      cd.queryButton->setVisible(false);
-      cd.resetButton->setVisible(false);
-      cd.computeButton->setVisible(false);
-      trd.saveButton->setVisible(false);
-      trd.insertButton->setVisible(false);
       trd.deleteButton->setVisible(false);
-      cd.frontButton->setVisible(false);
-      cd.backButton->setVisible(false);
+      trd.insertButton->setVisible(false);
+      trd.saveButton->setVisible(false);
       str = QString(tr("BiblioteQ: View Music CD Details (")) +
-	cd.id->text() + tr(")");
+	cd.id->text() +
+	tr(")");
       m_engWindowTitle = "View";
     }
 
+  cd.tracksButton->setEnabled(true);
   setReadOnlyFields(this, state != biblioteq::EDITABLE);
   setWindowTitle(str);
-  cd.tracksButton->setEnabled(true);
 }
