@@ -29,6 +29,7 @@
 #include "biblioteq_copy_editor.h"
 
 #include <QScrollBar>
+#include <QSettings>
 #include <QTimer>
 
 biblioteq_copy_editor::biblioteq_copy_editor
@@ -70,15 +71,15 @@ biblioteq_copy_editor::biblioteq_copy_editor
   m_speedy = speedy;
   m_spinbox = spinboxArg;
   m_uniqueIdArg = uniqueIdArg;
+  prepareIcons();
   qmain = biblioteq;
+  setGlobalFonts(font);
+  setWindowModality(Qt::ApplicationModal);
 
   if(!uniqueIdArg.trimmed().isEmpty())
     setWindowTitle(tr("BiblioteQ: Copy Browser (%1)").arg(uniqueIdArg));
   else
     setWindowTitle(tr("BiblioteQ: Copy Browser"));
-
-  setGlobalFonts(font);
-  setWindowModality(Qt::ApplicationModal);
 }
 
 biblioteq_copy_editor::~biblioteq_copy_editor()
@@ -142,9 +143,10 @@ QString biblioteq_copy_editor::saveCopies(void)
 				  "(item_oid, "
 				  "copy_number, "
 				  "copyid, "
-				  "status) "
+				  "status, "
+				  "notes) "
 				  "VALUES "
-				  "(?, ?, ?, ?)").arg
+				  "(?, ?, ?, ?, ?)").arg
 			  (m_itemType.toLower().remove(" ")));
 	  else
 	    query.prepare(QString("INSERT INTO %1_copy_info "
@@ -152,8 +154,9 @@ QString biblioteq_copy_editor::saveCopies(void)
 				  "copy_number, "
 				  "copyid, "
 				  "myoid, "
-				  "status) "
-				  "VALUES (?, ?, ?, ?, ?)").
+				  "status, "
+				  "notes) "
+				  "VALUES (?, ?, ?, ?, ?, ?)").
 			  arg(m_itemType.toLower().remove(" ")));
 
 	  query.addBindValue(copy->m_itemoid);
@@ -188,6 +191,7 @@ QString biblioteq_copy_editor::saveCopies(void)
 	    }
 
 	  query.addBindValue(copy->m_status);
+	  query.addBindValue(copy->m_notes);
 
 	  if(!query.exec())
 	    {
@@ -347,16 +351,11 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
 	  SIGNAL(clicked(void)),
 	  this,
 	  SLOT(slotCloseCopyEditor(void)));
-
-  QProgressDialog progress1(this);
-  QProgressDialog progress2(this);
-
-  m_cb.table->setColumnCount(0);
-  m_cb.table->setRowCount(0);
   list.append(tr("Title"));
   list.append(tr("Barcode"));
   list.append(tr("Availability"));
   list.append(tr("Status"));
+  list.append(tr("Notes"));
   list.append("ITEM_OID");
   list.append("Copy Number");
   m_columnHeaderIndexes.clear();
@@ -364,11 +363,13 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
   m_columnHeaderIndexes.append("Barcode");
   m_columnHeaderIndexes.append("Availability");
   m_columnHeaderIndexes.append("Status");
+  m_columnHeaderIndexes.append("Notes");
   m_columnHeaderIndexes.append("ITEM_OID");
   m_columnHeaderIndexes.append("Copy Number");
+  m_cb.table->setColumnCount(0);
   m_cb.table->setColumnCount(list.size());
   m_cb.table->setHorizontalHeaderLabels(list);
-  list.clear();
+  m_cb.table->setRowCount(0);
   m_cb.table->setRowCount(m_quantity);
   m_cb.table->scrollToTop();
   m_cb.table->horizontalScrollBar()->setValue(0);
@@ -381,6 +382,11 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
   m_cb.table->setColumnHidden(m_cb.table->columnCount() - 2, true);
   updateGeometry();
   show();
+  QApplication::processEvents();
+
+  QProgressDialog progress1(this);
+  QProgressDialog progress2(this);
+
   progress1.setLabelText(tr("Constructing objects..."));
   progress1.setMaximum(m_quantity);
   progress1.setMinimum(0);
@@ -393,14 +399,18 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
   for(i = 0; i < m_quantity && !progress1.wasCanceled(); i++)
     for(j = 0; j < m_cb.table->columnCount(); j++)
       {
-	if(j == STATUS)
+	if(j == static_cast<int> (Columns::STATUS))
 	  {
 	    comboBox = new QComboBox();
 	    comboBox->addItem(tr("Available"));
 	    comboBox->addItem(tr("Deleted"));
+	    comboBox->addItem(tr("Expired"));
 	    comboBox->addItem(tr("Lost"));
+	    comboBox->addItem(tr("Not Available"));
+	    comboBox->addItem(tr("Recalled"));
 	    comboBox->addItem(biblioteq::s_unknown);
 	    comboBox->setEnabled(!m_showForLending);
+	    biblioteq_misc_functions::sortCombinationBox(comboBox);
 	    goto done_label;
 	  }
 	else
@@ -410,27 +420,28 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
 
 	if(m_showForLending)
 	  item->setFlags(Qt::NoItemFlags);
-	else if(j == BARCODE)
+	else if(j == static_cast<int> (Columns::BARCODE) ||
+		j == static_cast<int> (Columns::NOTES))
 	  item->setFlags
 	    (Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 	else
 	  item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 
-	if(j == BARCODE)
-	  {
-	    if(!m_uniqueIdArg.isEmpty())
-	      item->setText(m_uniqueIdArg + "-" + QString::number(i + 1));
-	    else
-	      item->setText("");
-	  }
-	else if(j == AVAILABILITY)
+	if(j == static_cast<int> (Columns::AVAILABILITY))
 	  {
 	    if(m_showForLending)
 	      item->setText("0");
 	    else
 	      item->setText("1");
 	  }
-	else if(j == MYOID)
+	else if(j == static_cast<int> (Columns::BARCODE))
+	  {
+	    if(!m_uniqueIdArg.isEmpty())
+	      item->setText(m_uniqueIdArg + "-" + QString::number(i + 1));
+	    else
+	      item->setText("");
+	  }
+	else if(j == static_cast<int> (Columns::MYOID))
 	  item->setText(m_ioid);
 	else
 	  item->setText("");
@@ -470,6 +481,7 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
 			    "%1_copy_info.copyid, "
 			    "(1 - COUNT(item_borrower.copyid)), "
 			    "%1_copy_info.status, "
+			    "%1_copy_info.notes, "
 			    "%1_copy_info.item_oid, "
 			    "%1_copy_info.copy_number "
 			    "FROM "
@@ -484,6 +496,7 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
 			    "GROUP BY %1.title, "
 			    "%1_copy_info.copyid, "
 			    "%1_copy_info.status, "
+			    "%1_copy_info.notes, "
 			    "%1_copy_info.item_oid, "
 			    "%1_copy_info.copy_number "
 			    "ORDER BY %1_copy_info.copy_number").
@@ -560,7 +573,8 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
 	      {
 		str = query.value(j).toString().trimmed();
 
-		if(query.value(AVAILABILITY).toString().trimmed() == "0")
+		if(query.value(static_cast<int> (Columns::AVAILABILITY)).
+		   toString().trimmed() == "0")
 		  m_cb.table->item(row, j)->setFlags(Qt::NoItemFlags);
 		else if(m_showForLending)
 		  {
@@ -570,20 +584,21 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
 		    if(m_cb.table->currentRow() == -1)
 		      m_cb.table->selectRow(row);
 		  }
-		else if(j == BARCODE)
+		else if(j == static_cast<int> (Columns::BARCODE) ||
+			j == static_cast<int> (Columns::NOTES))
 		  m_cb.table->item(row, j)->setFlags
 		    (Qt::ItemIsEditable |
 		     Qt::ItemIsEnabled |
 		     Qt::ItemIsSelectable);
 
-		if(j == AVAILABILITY)
+		if(j == static_cast<int> (Columns::AVAILABILITY))
 		  m_cb.table->item(row, j)->setText
 		    (query.value(j).toString().trimmed());
 		else
 		  {
-		    if(i == 0 && j == TITLE)
+		    if(i == 0 && j == static_cast<int> (Columns::TITLE))
 		      m_cb.table->item(row, j)->setText(str);
-		    else if(j != TITLE)
+		    else if(j != static_cast<int> (Columns::TITLE))
 		      m_cb.table->item(row, j)->setText(str);
 		  }
 	      }
@@ -609,6 +624,32 @@ void biblioteq_copy_editor::populateCopiesEditor(void)
     QTimer::singleShot(250, this, SLOT(slotCheckoutCopy(void)));
 }
 
+void biblioteq_copy_editor::prepareIcons(void)
+{
+  QSettings setting;
+  auto index = setting.value("otheroptions/display_icon_set_index", 0).toInt();
+
+  if(index == 1)
+    {
+      // System.
+
+      m_cb.cancelButton->setIcon
+	(QIcon::fromTheme("window-close", QIcon(":/16x16/cancel.png")));
+      m_cb.deleteButton->setIcon
+	(QIcon::fromTheme("edit-delete", QIcon(":/16x16/eraser.png")));
+      m_cb.saveButton->setIcon
+	(QIcon::fromTheme("dialog-ok", QIcon(":/16x16/ok.png")));
+    }
+  else
+    {
+      // Faenza.
+
+      m_cb.cancelButton->setIcon(QIcon(":/16x16/cancel.png"));
+      m_cb.deleteButton->setIcon(QIcon(":/16x16/eraser.png"));
+      m_cb.saveButton->setIcon(QIcon(":/16x16/ok.png"));
+    }
+}
+
 void biblioteq_copy_editor::setGlobalFonts(const QFont &font)
 {
   setFont(font);
@@ -637,7 +678,8 @@ void biblioteq_copy_editor::slotCheckoutCopy(void)
   auto duedate = m_cb.dueDate->date().toString(biblioteq::s_databaseDateFormat);
   auto memberrow = qmain->getBB().table->currentRow();
 
-  if(copyrow < 0 || m_cb.table->item(copyrow, BARCODE) == nullptr)
+  if(copyrow < 0 ||
+     m_cb.table->item(copyrow, static_cast<int> (Columns::BARCODE)) == nullptr)
     {
       QMessageBox::critical(this,
 			    tr("BiblioteQ: User Error"),
@@ -645,13 +687,13 @@ void biblioteq_copy_editor::slotCheckoutCopy(void)
       QApplication::processEvents();
       return;
     }
-  else if((m_cb.table->item(copyrow, BARCODE)->flags() &
-	   Qt::ItemIsEnabled) == 0)
+  else if((m_cb.table->item(copyrow, static_cast<int> (Columns::BARCODE))->
+	   flags() & Qt::ItemIsEnabled) == 0)
     {
       QMessageBox::critical(this,
 			    tr("BiblioteQ: User Error"),
-			    tr("It appears that the copy you've selected "
-			       "is either unavailable or does not exist."));
+			    tr("It appears that the copy you have selected "
+			       "does not exist or is not available."));
       QApplication::processEvents();
       return;
     }
@@ -696,8 +738,8 @@ void biblioteq_copy_editor::slotCheckoutCopy(void)
     {
       QMessageBox::critical(this,
 			    tr("BiblioteQ: User Error"),
-			    tr("The copy that you have selected is either "
-			       "unavailable or is reserved."));
+			    tr("The copy that you have selected does "
+			       "not exist or is not available."));
       QApplication::processEvents();
       return;
     }
@@ -886,13 +928,17 @@ void biblioteq_copy_editor::slotDeleteCopy(void)
 
   if(isCheckedOut)
     {
-      if(m_cb.table->item(row, BARCODE) != nullptr)
-	m_cb.table->item(row, BARCODE)->setFlags(Qt::NoItemFlags);
+      if(m_cb.table->item(row, static_cast<int> (Columns::BARCODE)) != nullptr)
+	m_cb.table->item(row, static_cast<int> (Columns::BARCODE))->setFlags
+	  (Qt::NoItemFlags);
 
-      if(m_cb.table->item(row, AVAILABILITY) != nullptr)
+      if(m_cb.table->item(row, static_cast<int> (Columns::AVAILABILITY)) !=
+	 nullptr)
 	{
-	  m_cb.table->item(row, AVAILABILITY)->setFlags(Qt::NoItemFlags);
-	  m_cb.table->item(row, AVAILABILITY)->setText("0");
+	  m_cb.table->item(row, static_cast<int> (Columns::AVAILABILITY))->
+	    setFlags(Qt::NoItemFlags);
+	  m_cb.table->item(row, static_cast<int> (Columns::AVAILABILITY))->
+	    setText("0");
 	}
 
       QMessageBox::critical(this,
@@ -917,6 +963,8 @@ void biblioteq_copy_editor::slotDeleteCopy(void)
       QApplication::processEvents();
       return;
     }
+  else
+    m_cb.deleteButton->animate(2500);
 
   m_cb.table->removeRow(m_cb.table->currentRow());
 }
@@ -930,40 +978,42 @@ void biblioteq_copy_editor::slotSaveCopies(void)
   QTableWidgetItem *item1 = nullptr;
   QTableWidgetItem *item2 = nullptr;
   QTableWidgetItem *item3 = nullptr;
+  QTableWidgetItem *item4 = nullptr;
   copy_class *copy = nullptr;
   int i = 0;
 
   m_cb.table->setFocus();
 
   for(i = 0; i < m_cb.table->rowCount(); i++)
-    if(m_cb.table->item(i, BARCODE) != nullptr &&
-       m_cb.table->item(i, BARCODE)->text().trimmed().isEmpty())
+    if(m_cb.table->item(i, static_cast<int> (Columns::BARCODE)) != nullptr &&
+       m_cb.table->item(i, static_cast<int> (Columns::BARCODE))->
+       text().trimmed().isEmpty())
       {
 	errormsg = QString(tr("Row number ")) +
 	  QString::number(i + 1) +
 	  tr(" contains an empty Barcode.");
 	QMessageBox::critical(this, tr("BiblioteQ: User Error"), errormsg);
 	QApplication::processEvents();
-	duplicates.clear();
 	return;
       }
-    else if(m_cb.table->item(i, BARCODE) != nullptr)
+    else if(m_cb.table->item(i, static_cast<int> (Columns::BARCODE)) != nullptr)
       {
-	if(duplicates.contains(m_cb.table->item(i, BARCODE)->text()))
+	if(duplicates.
+	   contains(m_cb.table->item(i, static_cast<int> (Columns::BARCODE))->
+		    text()))
 	  {
 	    errormsg = QString(tr("Row number ")) +
 	      QString::number(i + 1) +
 	      tr(" contains a duplicate Barcode.");
 	    QMessageBox::critical(this, tr("BiblioteQ: User Error"), errormsg);
 	    QApplication::processEvents();
-	    duplicates.clear();
 	    return;
 	  }
 	else
-	  duplicates.append(m_cb.table->item(i, BARCODE)->text());
+	  duplicates.append
+	    (m_cb.table->item(i, static_cast<int> (Columns::BARCODE))->text());
       }
 
-  duplicates.clear();
   QApplication::setOverrideCursor(Qt::WaitCursor);
   clearCopiesList();
 
@@ -986,20 +1036,24 @@ void biblioteq_copy_editor::slotSaveCopies(void)
 
   for(i = 0; i < m_cb.table->rowCount(); i++)
     {
-      comboBox = qobject_cast<QComboBox *> (m_cb.table->cellWidget(i, STATUS));
-      item1 = m_cb.table->item(i, BARCODE);
-      item2 = m_cb.table->item(i, COPY_NUMBER);
-      item3 = m_cb.table->item(i, MYOID);
+      comboBox = qobject_cast<QComboBox *>
+	(m_cb.table->cellWidget(i, static_cast<int> (Columns::STATUS)));
+      item1 = m_cb.table->item(i, static_cast<int> (Columns::BARCODE));
+      item2 = m_cb.table->item(i, static_cast<int> (Columns::COPY_NUMBER));
+      item3 = m_cb.table->item(i, static_cast<int> (Columns::MYOID));
+      item4 = m_cb.table->item(i, static_cast<int> (Columns::NOTES));
 
       if(comboBox == nullptr ||
 	 item1 == nullptr ||
 	 item2 == nullptr ||
-	 item3 == nullptr)
+	 item3 == nullptr ||
+	 item4 == nullptr)
 	continue;
 
       copy = new copy_class(item1->text().trimmed(),            // Copy ID
 			    item2->text(),                      // Copy Number
 			    item3->text(),                      // Item OID
+			    item4->text(),                      // Notes
 			    comboBox->currentText().trimmed()); // Status
       m_copies.append(copy);
     }
@@ -1058,6 +1112,8 @@ void biblioteq_copy_editor::slotSaveCopies(void)
       QApplication::processEvents();
       return;
     }
+  else
+    m_cb.saveButton->animate(2500);
 
   auto availability = biblioteq_misc_functions::getAvailability
     (m_ioid, qmain->getDB(), m_itemType, errorstr);
