@@ -29,6 +29,7 @@
 #include "biblioteq_copy_editor_book.h"
 
 #include <QScrollBar>
+#include <QSettings>
 
 biblioteq_copy_editor_book::biblioteq_copy_editor_book
 (QWidget *parent,
@@ -52,6 +53,7 @@ biblioteq_copy_editor_book::biblioteq_copy_editor_book
   m_showForLending = showForLendingArg;
   m_spinbox = spinboxArg;
   m_uniqueIdArg = uniqueIdArg.trimmed();
+  prepareIcons();
   qmain = biblioteq;
   setGlobalFonts(font);
   setWindowModality(Qt::ApplicationModal);
@@ -124,8 +126,9 @@ QString biblioteq_copy_editor_book::saveCopies(void)
 				  "copyid, "
 				  "originality, "
 				  "condition, "
-				  "status) "
-				  "VALUES (?, ?, ?, ?, ?, ?)").arg
+				  "status, "
+				  "notes) "
+				  "VALUES (?, ?, ?, ?, ?, ?, ?)").arg
 			  (m_itemType.toLower().remove(" ")));
 	  else
 	    query.prepare(QString("INSERT INTO %1_copy_info "
@@ -135,8 +138,9 @@ QString biblioteq_copy_editor_book::saveCopies(void)
 				  "originality, "
 				  "condition, "
 				  "myoid, "
-				  "status) "
-				  "VALUES (?, ?, ?, ?, ?, ?, ?)").arg
+				  "status, "
+				  "notes) "
+				  "VALUES (?, ?, ?, ?, ?, ?, ?, ?)").arg
 			  (m_itemType.toLower().remove(" ")));
 
 	  query.addBindValue(copy->m_itemoid);
@@ -173,6 +177,7 @@ QString biblioteq_copy_editor_book::saveCopies(void)
 	    }
 
 	  query.addBindValue(copy->m_status);
+	  query.addBindValue(copy->m_notes);
 
 	  if(!query.exec())
 	    {
@@ -304,18 +309,13 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 	  SIGNAL(clicked(void)),
 	  this,
 	  SLOT(slotCloseCopyEditor(void)));
-
-  QProgressDialog progress1(this);
-  QProgressDialog progress2(this);
-
-  m_cb.table->setColumnCount(0);
-  m_cb.table->setRowCount(0);
   list.append(tr("Title"));
   list.append(tr("Barcode"));
   list.append(tr("Availability"));
   list.append(tr("Originality"));
   list.append(tr("Condition"));
   list.append(tr("Status"));
+  list.append(tr("Notes"));
   list.append("ITEM_OID");
   list.append("Copy Number");
   m_columnHeaderIndexes.clear();
@@ -325,14 +325,16 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
   m_columnHeaderIndexes.append("Originality");
   m_columnHeaderIndexes.append("Condition");
   m_columnHeaderIndexes.append("Status");
+  m_columnHeaderIndexes.append("Notes");
   m_columnHeaderIndexes.append("ITEM_OID");
   m_columnHeaderIndexes.append("Copy Number");
+  m_cb.table->horizontalScrollBar()->setValue(0);
+  m_cb.table->scrollToTop();
+  m_cb.table->setColumnCount(0);
   m_cb.table->setColumnCount(list.size());
   m_cb.table->setHorizontalHeaderLabels(list);
-  list.clear();
+  m_cb.table->setRowCount(0);
   m_cb.table->setRowCount(m_quantity);
-  m_cb.table->scrollToTop();
-  m_cb.table->horizontalScrollBar()->setValue(0);
 
   /*
   ** Hide the Copy Number and ITEM_OID columns.
@@ -342,6 +344,11 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
   m_cb.table->setColumnHidden(m_cb.table->columnCount() - 2, true);
   updateGeometry();
   show();
+  QApplication::processEvents();
+
+  QProgressDialog progress1(this);
+  QProgressDialog progress2(this);
+
   progress1.setLabelText(tr("Constructing objects..."));
   progress1.setMaximum(m_quantity);
   progress1.setMinimum(0);
@@ -354,7 +361,8 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
   for(i = 0; i < m_quantity && !progress1.wasCanceled(); i++)
     {
       for(j = 0; j < m_cb.table->columnCount(); j++)
-	if(j == CONDITION || j == ORIGINALITY)
+	if(j == static_cast<int> (Columns::CONDITION) ||
+	   j == static_cast<int> (Columns::ORIGINALITY))
 	  {
 	    QString error("");
 	    QStringList list;
@@ -364,7 +372,7 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 	      (40, 20, QSizePolicy::Expanding, QSizePolicy::Expanding);
 	    auto widget = new QWidget();
 
-	    if(j == ORIGINALITY)
+	    if(j == static_cast<int> (Columns::ORIGINALITY))
 	      list = biblioteq_misc_functions::getBookOriginality
 		(qmain->getDB(), error);
 	    else
@@ -375,13 +383,14 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 	    comboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 	    comboBox->setSizePolicy
 	      (QSizePolicy::Preferred, QSizePolicy::Minimum);
+	    biblioteq_misc_functions::sortCombinationBox(comboBox);
 	    layout->addWidget(comboBox);
 	    layout->addSpacerItem(spacer);
 	    layout->setContentsMargins(0, 0, 0, 0);
 	    widget->setLayout(layout);
 	    m_cb.table->setCellWidget(i, j, widget);
 	  }
-	else if(j == STATUS)
+	else if(j == static_cast<int> (Columns::STATUS))
 	  {
 	    auto comboBox = new QComboBox();
 	    auto layout = new QHBoxLayout();
@@ -391,11 +400,15 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 
 	    comboBox->addItem(tr("Available"));
 	    comboBox->addItem(tr("Deleted"));
+	    comboBox->addItem(tr("Expired"));
 	    comboBox->addItem(tr("Lost"));
+	    comboBox->addItem(tr("Not Available"));
+	    comboBox->addItem(tr("Recalled"));
 	    comboBox->addItem(biblioteq::s_unknown);
 	    comboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 	    comboBox->setSizePolicy
 	      (QSizePolicy::Preferred, QSizePolicy::Minimum);
+	    biblioteq_misc_functions::sortCombinationBox(comboBox);
 	    layout->addWidget(comboBox);
 	    layout->addSpacerItem(spacer);
 	    layout->setContentsMargins(0, 0, 0, 0);
@@ -408,28 +421,29 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 
 	    if(m_showForLending)
 	      item->setFlags(Qt::NoItemFlags);
-	    else if(j == BARCODE)
+	    else if(j == static_cast<int> (Columns::BARCODE) ||
+		    j == static_cast<int> (Columns::NOTES))
 	      item->setFlags(Qt::ItemIsEditable |
 			     Qt::ItemIsEnabled |
 			     Qt::ItemIsSelectable);
 	    else
 	      item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 
-	    if(j == BARCODE)
-	      {
-		if(!m_uniqueIdArg.isEmpty())
-		  item->setText(m_uniqueIdArg + "-" + QString::number(i + 1));
-		else
-		  item->setText("");
-	      }
-	    else if(j == AVAILABILITY)
+	    if(j == static_cast<int> (Columns::AVAILABILITY))
 	      {
 		if(m_showForLending)
 		  item->setText("0");
 		else
 		  item->setText("1");
 	      }
-	    else if(j == MYOID)
+	    else if(j == static_cast<int> (Columns::BARCODE))
+	      {
+		if(!m_uniqueIdArg.isEmpty())
+		  item->setText(m_uniqueIdArg + "-" + QString::number(i + 1));
+		else
+		  item->setText("");
+	      }
+	    else if(j == static_cast<int> (Columns::MYOID))
 	      item->setText(m_ioid);
 	    else
 	      item->setText("");
@@ -452,6 +466,7 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 			"%1_copy_info.originality, "
 			"%1_copy_info.condition, "
 			"%1_copy_info.status, "
+			"%1_copy_info.notes, "
 			"%1_copy_info.item_oid, "
 			"%1_copy_info.copy_number "
 			"FROM "
@@ -468,6 +483,7 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 			"%1_copy_info.originality, "
 			"%1_copy_info.condition, "
 			"%1_copy_info.status, "
+			"%1_copy_info.notes, "
 			"%1_copy_info.item_oid, "
 			"%1_copy_info.copy_number "
 			"ORDER BY %1_copy_info.copy_number").arg
@@ -526,7 +542,8 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 	      {
 		str = query.value(j).toString().trimmed();
 
-		if(query.value(AVAILABILITY).toString().trimmed() == "0")
+		if(query.value(static_cast<int> (Columns::AVAILABILITY)).
+		   toString().trimmed() == "0")
 		  m_cb.table->item(row, j)->setFlags(Qt::NoItemFlags);
 		else if(m_showForLending)
 		  {
@@ -536,18 +553,19 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
 		    if(m_cb.table->currentRow() == -1)
 		      m_cb.table->selectRow(row);
 		  }
-		else if(j == BARCODE)
+		else if(j == static_cast<int> (Columns::BARCODE) ||
+			j == static_cast<int> (Columns::NOTES))
 		  m_cb.table->item(row, j)->setFlags
 		    (Qt::ItemIsEditable |
 		     Qt::ItemIsEnabled |
 		     Qt::ItemIsSelectable);
 
-		if(j == AVAILABILITY)
+		if(j == static_cast<int> (Columns::AVAILABILITY))
 		  m_cb.table->item(row, j)->setText
 		    (query.value(j).toString().trimmed());
 		else
 		  {
-		    if(j == TITLE)
+		    if(j == static_cast<int> (Columns::TITLE))
 		      {
 			if(i == 0)
 			  m_cb.table->item(row, j)->setText(str);
@@ -595,6 +613,32 @@ void biblioteq_copy_editor_book::populateCopiesEditor(void)
   m_cb.table->resizeRowsToContents();
 }
 
+void biblioteq_copy_editor_book::prepareIcons(void)
+{
+  QSettings setting;
+  auto index = setting.value("otheroptions/display_icon_set_index", 0).toInt();
+
+  if(index == 1)
+    {
+      // System.
+
+      m_cb.cancelButton->setIcon
+	(QIcon::fromTheme("window-close", QIcon(":/16x16/cancel.png")));
+      m_cb.deleteButton->setIcon
+	(QIcon::fromTheme("edit-delete", QIcon(":/16x16/eraser.png")));
+      m_cb.saveButton->setIcon
+	(QIcon::fromTheme("dialog-ok", QIcon(":/16x16/ok.png")));
+    }
+  else
+    {
+      // Faenza.
+
+      m_cb.cancelButton->setIcon(QIcon(":/16x16/cancel.png"));
+      m_cb.deleteButton->setIcon(QIcon(":/16x16/eraser.png"));
+      m_cb.saveButton->setIcon(QIcon(":/16x16/ok.png"));
+    }
+}
+
 void biblioteq_copy_editor_book::slotDeleteCopy(void)
 {
   /*
@@ -636,15 +680,20 @@ void biblioteq_copy_editor_book::slotDeleteCopy(void)
 
   if(isCheckedOut)
     {
-      if(m_cb.table->item(row, BARCODE) != nullptr)
-	m_cb.table->item(row, BARCODE)->setFlags(Qt::NoItemFlags);
-
-      if(m_cb.table->item(row, AVAILABILITY) != nullptr)
+      if(m_cb.table->item(row, static_cast<int> (Columns::AVAILABILITY)) !=
+	 nullptr)
 	{
-	  m_cb.table->item(row, AVAILABILITY)->setFlags(Qt::NoItemFlags);
-	  m_cb.table->item(row, AVAILABILITY)->setText("0");
+	  m_cb.table->item
+	    (row, static_cast<int> (Columns::AVAILABILITY))->setFlags
+	    (Qt::NoItemFlags);
+	  m_cb.table->item
+	    (row, static_cast<int> (Columns::AVAILABILITY))->setText("0");
 	}
 
+      if(m_cb.table->item(row, static_cast<int> (Columns::BARCODE)) != nullptr)
+	m_cb.table->item(row, static_cast<int> (Columns::BARCODE))->setFlags
+	  (Qt::NoItemFlags);
+
       QMessageBox::critical(this,
 			    tr("BiblioteQ: User Error"),
 			    tr("It appears that the copy you selected to "
@@ -667,6 +716,8 @@ void biblioteq_copy_editor_book::slotDeleteCopy(void)
       QApplication::processEvents();
       return;
     }
+  else
+    m_cb.deleteButton->animate(2500);
 
   m_cb.table->removeRow(m_cb.table->currentRow());
 }
@@ -682,38 +733,42 @@ void biblioteq_copy_editor_book::slotSaveCopies(void)
   QTableWidgetItem *item1 = nullptr;
   QTableWidgetItem *item2 = nullptr;
   QTableWidgetItem *item3 = nullptr;
+  QTableWidgetItem *item4 = nullptr;
   copy_class *copy = nullptr;
   int i = 0;
 
   m_cb.table->setFocus();
 
   for(i = 0; i < m_cb.table->rowCount(); i++)
-    if(m_cb.table->item(i, BARCODE) != nullptr &&
-       m_cb.table->item(i, BARCODE)->text().trimmed().isEmpty())
+    if(m_cb.table->item(i, static_cast<int> (Columns::BARCODE)) != nullptr &&
+       m_cb.table->item(i, static_cast<int> (Columns::BARCODE))->
+       text().trimmed().isEmpty())
       {
-	errormsg = QString(tr("Row number ")) + QString::number(i + 1) +
+	errormsg = tr("Row number ") +
+	  QString::number(i + 1) +
 	  tr(" contains an empty Barcode.");
 	QMessageBox::critical(this, tr("BiblioteQ: User Error"), errormsg);
 	QApplication::processEvents();
-	duplicates.clear();
 	return;
       }
-    else if(m_cb.table->item(i, BARCODE) != nullptr)
+    else if(m_cb.table->item(i, static_cast<int> (Columns::BARCODE)) != nullptr)
       {
-	if(duplicates.contains(m_cb.table->item(i, BARCODE)->text()))
+	if(duplicates.
+	   contains(m_cb.table->item(i, static_cast<int> (Columns::BARCODE))->
+		    text()))
 	  {
-	    errormsg = QString(tr("Row number ")) + QString::number(i + 1) +
+	    errormsg = tr("Row number ") +
+	      QString::number(i + 1) +
 	      tr(" contains a duplicate Barcode.");
 	    QMessageBox::critical(this, tr("BiblioteQ: User Error"), errormsg);
 	    QApplication::processEvents();
-	    duplicates.clear();
 	    return;
 	  }
 	else
-	  duplicates.append(m_cb.table->item(i, BARCODE)->text());
+	  duplicates.append
+	    (m_cb.table->item(i, static_cast<int> (Columns::BARCODE))->text());
       }
 
-  duplicates.clear();
   QApplication::setOverrideCursor(Qt::WaitCursor);
   clearCopiesList();
 
@@ -736,9 +791,12 @@ void biblioteq_copy_editor_book::slotSaveCopies(void)
 
   for(i = 0; i < m_cb.table->rowCount(); i++)
     {
-      auto widget1 = m_cb.table->cellWidget(i, ORIGINALITY);
-      auto widget2 = m_cb.table->cellWidget(i, CONDITION);
-      auto widget3 = m_cb.table->cellWidget(i, STATUS);
+      auto widget1 = m_cb.table->cellWidget
+	(i, static_cast<int> (Columns::ORIGINALITY));
+      auto widget2 = m_cb.table->cellWidget
+	(i, static_cast<int> (Columns::CONDITION));
+      auto widget3 = m_cb.table->cellWidget
+	(i, static_cast<int> (Columns::STATUS));
 
       if(!widget1 || !widget2 || !widget3)
 	continue;
@@ -746,11 +804,18 @@ void biblioteq_copy_editor_book::slotSaveCopies(void)
       comboBox1 = widget1->findChild<QComboBox *> ();
       comboBox2 = widget2->findChild<QComboBox *> ();
       comboBox3 = widget3->findChild<QComboBox *> ();
-      item1 = m_cb.table->item(i, BARCODE);
-      item2 = m_cb.table->item(i, COPY_NUMBER);
-      item3 = m_cb.table->item(i, MYOID);
+      item1 = m_cb.table->item(i, static_cast<int> (Columns::BARCODE));
+      item2 = m_cb.table->item(i, static_cast<int> (Columns::COPY_NUMBER));
+      item3 = m_cb.table->item(i, static_cast<int> (Columns::MYOID));
+      item4 = m_cb.table->item(i, static_cast<int> (Columns::NOTES));
 
-      if(!comboBox1 || !comboBox2 || !comboBox3 || !item1 || !item2 || !item3)
+      if(!comboBox1 ||
+	 !comboBox2 ||
+	 !comboBox3 ||
+	 !item1 ||
+	 !item2 ||
+	 !item3 ||
+	 !item4)
 	continue;
 
       copy = new copy_class
@@ -758,6 +823,7 @@ void biblioteq_copy_editor_book::slotSaveCopies(void)
 	 item1->text().trimmed(),
 	 item2->text(),
 	 item3->text(),
+	 item4->text(),
 	 comboBox1->currentText().trimmed(),
 	 comboBox3->currentText().trimmed());
       m_copies.append(copy);
@@ -817,6 +883,8 @@ void biblioteq_copy_editor_book::slotSaveCopies(void)
       QApplication::processEvents();
       return;
     }
+  else
+    m_cb.saveButton->animate(2500);
 
   auto availability = biblioteq_misc_functions::getAvailability
     (m_ioid, qmain->getDB(), m_itemType, errorstr);
