@@ -186,6 +186,7 @@ biblioteq_dbenumerations::biblioteq_dbenumerations(biblioteq *parent):
       m_ui.minimumDaysTable->setCellWidget(i, 1, lineEdit);
     }
 
+  prepareIcons();
   setAttribute(Qt::WA_DeleteOnClose, true);
 }
 
@@ -214,7 +215,15 @@ void biblioteq_dbenumerations::clear(void)
   m_ui.bc_favorite->clear();
   m_ui.bo_favorite->clear();
   m_ui.bta_favorite->clear();
-  m_ui.cdf_favorite->clear();
+  m_ui.cf_favorite->clear();
+  m_ui.dar_favorite->clear();
+  m_ui.dr_favorite->clear();
+  m_ui.drs_favorite->clear();
+  m_ui.gldt_favorite->clear();
+  m_ui.language_favorite->clear();
+  m_ui.monetary_units_favorite->clear();
+  m_ui.vgp_favorite->clear();
+  m_ui.vgr_favorite->clear();
 
   foreach(auto listwidget, findChildren<QListWidget *> ())
     listwidget->clear();
@@ -227,8 +236,8 @@ void biblioteq_dbenumerations::clear(void)
 
 void biblioteq_dbenumerations::closeEvent(QCloseEvent *event)
 {
-  QHash<QWidget *, QStringList> listData;
   QHash<QWidget *, QMap<QString, QString> > tableData;
+  QHash<QWidget *, QStringList> listData;
 
   saveData(listData, tableData);
 
@@ -262,7 +271,6 @@ void biblioteq_dbenumerations::populateWidgets(void)
 
   clear();
 
-  QList<QPair<QString, QString> > pairList;
   QSettings settings;
   QString errorstr("");
   QStringList list;
@@ -287,6 +295,7 @@ void biblioteq_dbenumerations::populateWidgets(void)
   for(int i = 0; i < tables.size(); i++)
     {
       QComboBox *combobox = nullptr;
+      QList<QPair<QString, QString> > pairList;
       QListWidget *listwidget = nullptr;
       QTableWidget *tablewidget = nullptr;
       const auto &str(tables.at(i));
@@ -323,37 +332,42 @@ void biblioteq_dbenumerations::populateWidgets(void)
 	}
       else if(str == "cd_formats")
 	{
-	  combobox = m_ui.cdf_favorite;
+	  combobox = m_ui.cf_favorite;
 	  list = biblioteq_misc_functions::getCDFormats
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.cdFormatsList;
 	}
       else if(str == "dvd_aspect_ratios")
 	{
+	  combobox = m_ui.dar_favorite;
 	  list = biblioteq_misc_functions::getDVDAspectRatios
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.dvdAspectRatiosList;
 	}
       else if(str == "dvd_ratings")
 	{
+	  combobox = m_ui.dr_favorite;
 	  list = biblioteq_misc_functions::getDVDRatings
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.dvdRatingsList;
 	}
       else if(str == "dvd_regions")
 	{
+	  combobox = m_ui.drs_favorite;
 	  list = biblioteq_misc_functions::getDVDRegions
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.dvdRegionsList;
 	}
       else if(str == "grey_literature_types")
 	{
+	  combobox = m_ui.gldt_favorite;
 	  list = biblioteq_misc_functions::getGreyLiteratureTypes
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.greyLiteratureTypes;
 	}
       else if(str == "languages")
 	{
+	  combobox = m_ui.language_favorite;
 	  list = biblioteq_misc_functions::getLanguages
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.languagesList;
@@ -372,18 +386,21 @@ void biblioteq_dbenumerations::populateWidgets(void)
 	}
       else if(str == "monetary_units")
 	{
+	  combobox = m_ui.monetary_units_favorite;
 	  list = biblioteq_misc_functions::getMonetaryUnits
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.monetaryUnitsList;
 	}
       else if(str == "videogame_platforms")
 	{
+	  combobox = m_ui.vgp_favorite;
 	  list = biblioteq_misc_functions::getVideoGamePlatforms
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.videoGamePlatformsList;
 	}
       else if(str == "videogame_ratings")
 	{
+	  combobox = m_ui.vgr_favorite;
 	  list = biblioteq_misc_functions::getVideoGameRatings
 	    (qmain->getDB(), errorstr);
 	  listwidget = m_ui.videoGameRatingsList;
@@ -450,28 +467,33 @@ void biblioteq_dbenumerations::populateWidgets(void)
 		   << tr("Music CD")
 		   << tr("Photograph Collection")
 		   << tr("Video Game");
+	      std::sort(list.begin(), list.end());
 	      comboBox->addItems(list);
 
 	      if(pairList.at(j).first == "Book")
-		comboBox->setCurrentIndex(0);
+		comboBox->setCurrentIndex(comboBox->findText(tr("Book")));
 	      else if(pairList.at(j).first == "CD")
-		comboBox->setCurrentIndex(5);
+		comboBox->setCurrentIndex(comboBox->findText(tr("Music CD")));
 	      else if(pairList.at(j).first == "DVD")
-		comboBox->setCurrentIndex(1);
+		comboBox->setCurrentIndex(comboBox->findText(tr("DVD")));
 	      else if(pairList.at(j).first == "Grey Literature")
-		comboBox->setCurrentIndex(2);
+		comboBox->setCurrentIndex
+		  (comboBox->findText(tr("Grey Literature")));
 	      else if(pairList.at(j).first == "Journal")
-		comboBox->setCurrentIndex(3);
+		comboBox->setCurrentIndex(comboBox->findText(tr("Journal")));
 	      else if(pairList.at(j).first == "Magazine")
-		comboBox->setCurrentIndex(4);
+		comboBox->setCurrentIndex(comboBox->findText(tr("Magazine")));
 	      else if(pairList.at(j).first == "Photograph Collection")
-		comboBox->setCurrentIndex(6);
+		comboBox->setCurrentIndex
+		  (comboBox->findText(tr("Photograph Collection")));
 	      else if(pairList.at(j).first == "Video Game")
-		comboBox->setCurrentIndex(7);
+		comboBox->setCurrentIndex(comboBox->findText("Video Game"));
+
+	      if(comboBox->currentIndex() < 0)
+		comboBox->setCurrentIndex(0);
 
 	      comboBox->setSizePolicy
 		(QSizePolicy::Preferred, QSizePolicy::Minimum);
-	      list.clear();
 	      item->setFlags
 		(Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 	      widget->setLayout(layout);
@@ -496,9 +518,6 @@ void biblioteq_dbenumerations::populateWidgets(void)
 
 	  m_ui.minimumDaysTable->resizeColumnToContents(0);
 	}
-
-      list.clear();
-      pairList.clear();
     }
 
   m_listData.clear();
@@ -507,6 +526,46 @@ void biblioteq_dbenumerations::populateWidgets(void)
   m_ui.bookBindingsList->setFocus();
 }
 
+void biblioteq_dbenumerations::prepareIcons(void)
+{
+  QSettings setting;
+  auto index = setting.value("otheroptions/display_icon_set_index", 0).toInt();
+
+  if(index == 1)
+    {
+      // System.
+
+      foreach(auto toolButton, findChildren<QToolButton *> ())
+	if(toolButton->objectName().startsWith("add"))
+	  toolButton->setIcon
+	    (QIcon::fromTheme("list-add", QIcon(":/16x16/add.png")));
+	else if(toolButton->objectName().startsWith("remove"))
+	  toolButton->setIcon
+	    (QIcon::fromTheme("list-remove", QIcon(":/16x16/eraser.png")));
+
+      m_ui.cancelButton->setIcon
+	(QIcon::fromTheme("window-close", QIcon(":/32x32/cancel.png")));
+      m_ui.reloadButton->setIcon
+	(QIcon::fromTheme("view-refresh", QIcon(":/32x32/reload.png")));
+      m_ui.saveButton->setIcon
+	(QIcon::fromTheme("document-save", QIcon(":/32x32/save.png")));
+    }
+  else
+    {
+      // Faenza.
+
+      foreach(auto toolButton, findChildren<QToolButton *> ())
+	if(toolButton->objectName().startsWith("add"))
+	  toolButton->setIcon(QIcon(":/16x16/add.png"));
+	else if(toolButton->objectName().startsWith("remove"))
+	  toolButton->setIcon(QIcon(":/16x16/eraser.png"));
+
+      m_ui.cancelButton->setIcon(QIcon(":/32x32/cancel.png"));
+      m_ui.reloadButton->setIcon(QIcon(":/32x32/reload.png"));
+      m_ui.saveButton->setIcon(QIcon(":/32x32/save.png"));
+    }
+}
+
 void biblioteq_dbenumerations::saveData
 (QHash<QWidget *, QStringList> &listData,
  QHash<QWidget *, QMap<QString, QString> > &tableData)
@@ -585,6 +644,16 @@ void biblioteq_dbenumerations::setGlobalFonts(const QFont &font)
   update();
 }
 
+void biblioteq_dbenumerations::setPage(const Page page)
+{
+  if(page == Page::ReservationMinimumDays)
+    {
+      m_ui.section->setCurrentIndex
+	(m_ui.section->findText(tr("Reservations Minimum Days")));
+      slotScrollToSection(m_ui.section->currentIndex());
+    }
+}
+
 void biblioteq_dbenumerations::show(QMainWindow *parent, const bool populate)
 {
   auto wasVisible = isVisible();
@@ -691,9 +760,9 @@ void biblioteq_dbenumerations::slotAdd(void)
 	   << tr("Music CD")
 	   << tr("Photograph Collection")
 	   << tr("Video Game");
+      std::sort(list.begin(), list.end());
       comboBox->addItems(list);
       comboBox->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
-      list.clear();
       item->setFlags
 	(Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable);
       widget->setLayout(layout);
@@ -743,8 +812,8 @@ void biblioteq_dbenumerations::slotClose(void)
 
 void biblioteq_dbenumerations::slotReload(void)
 {
-  QHash<QWidget *, QStringList> listData;
   QHash<QWidget *, QMap<QString, QString> > tableData;
+  QHash<QWidget *, QStringList> listData;
 
   saveData(listData, tableData);
 
@@ -886,29 +955,53 @@ void biblioteq_dbenumerations::slotSave(void)
 	}
       else if(tables.at(i) == "cd_formats")
 	{
-	  combobox = m_ui.cdf_favorite;
+	  combobox = m_ui.cf_favorite;
 	  listwidget = m_ui.cdFormatsList;
 	}
       else if(tables.at(i) == "dvd_aspect_ratios")
-	listwidget = m_ui.dvdAspectRatiosList;
+	{
+	  combobox = m_ui.dar_favorite;
+	  listwidget = m_ui.dvdAspectRatiosList;
+	}
       else if(tables.at(i) == "dvd_ratings")
-	listwidget = m_ui.dvdRatingsList;
+	{
+	  combobox = m_ui.dr_favorite;
+	  listwidget = m_ui.dvdRatingsList;
+	}
       else if(tables.at(i) == "dvd_regions")
-	listwidget = m_ui.dvdRegionsList;
+	{
+	  combobox = m_ui.drs_favorite;
+	  listwidget = m_ui.dvdRegionsList;
+	}
       else if(tables.at(i) == "grey_literature_types")
-	listwidget = m_ui.greyLiteratureTypes;
+	{
+	  combobox = m_ui.gldt_favorite;
+	  listwidget = m_ui.greyLiteratureTypes;
+	}
       else if(tables.at(i) == "languages")
-	listwidget = m_ui.languagesList;
+	{
+	  combobox = m_ui.language_favorite;
+	  listwidget = m_ui.languagesList;
+	}
       else if(tables.at(i) == "locations")
 	tablewidget = m_ui.locationsTable;
       else if(tables.at(i) == "minimum_days")
 	tablewidget = m_ui.minimumDaysTable;
       else if(tables.at(i) == "monetary_units")
-	listwidget = m_ui.monetaryUnitsList;
+	{
+	  combobox = m_ui.monetary_units_favorite;
+	  listwidget = m_ui.monetaryUnitsList;
+	}
       else if(tables.at(i) == "videogame_platforms")
-	listwidget = m_ui.videoGamePlatformsList;
+	{
+	  combobox = m_ui.vgp_favorite;
+	  listwidget = m_ui.videoGamePlatformsList;
+	}
       else if(tables.at(i) == "videogame_ratings")
-	listwidget = m_ui.videoGameRatingsList;
+	{
+	  combobox = m_ui.vgr_favorite;
+	  listwidget = m_ui.videoGameRatingsList;
+	}
 
       if(listwidget)
 	{
