@@ -34,6 +34,7 @@
 #include <QCryptographicHash>
 #include <QFileDialog>
 #include <QInputDialog>
+#include <QSettings>
 #include <QShortcut>
 #include <QSqlField>
 #include <QSqlRecord>
@@ -143,6 +144,10 @@ biblioteq_grey_literature::biblioteq_grey_literature(biblioteq *parentArg,
 	  SIGNAL(fontChanged(const QFont &)),
 	  this,
 	  SLOT(setGlobalFonts(const QFont &)));
+  connect(qmain,
+	  SIGNAL(otherOptionsSaved(void)),
+	  this,
+	  SLOT(slotPrepareIcons(void)));
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
   new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_S),
 		this,
@@ -153,7 +158,7 @@ biblioteq_grey_literature::biblioteq_grey_literature(biblioteq *parentArg,
 		SLOT(slotGo(void)));
 #endif
   QApplication::setOverrideCursor(Qt::WaitCursor);
-  m_ui.files->setColumnHidden(MYOID, true);
+  m_ui.files->setColumnHidden(static_cast<int> (Columns::MYOID), true);
   m_ui.files->verticalHeader()->setSectionResizeMode(QHeaderView::Fixed);
 
   QString errorstr("");
@@ -167,14 +172,18 @@ biblioteq_grey_literature::biblioteq_grey_literature(biblioteq *parentArg,
   qmain->addError
     (QString(tr("Database Error")),
      QString(tr("Unable to retrieve the grey literature locations.")),
-     errorstr, __FILE__, __LINE__);
+     errorstr,
+     __FILE__,
+     __LINE__);
   m_ui.type->addItems
     (biblioteq_misc_functions::getGreyLiteratureTypes(qmain->getDB(),
 						      errorstr));
   qmain->addError
     (QString(tr("Database Error")),
      QString(tr("Unable to retrieve the grey literature document types.")),
-     errorstr, __FILE__, __LINE__);
+     errorstr,
+     __FILE__,
+     __LINE__);
 
   if(m_ui.location->findText(biblioteq::s_unknown) == -1)
     m_ui.location->addItem(biblioteq::s_unknown);
@@ -328,7 +337,7 @@ void biblioteq_grey_literature::closeEvent(QCloseEvent *e)
 	   question(this,
 		    tr("BiblioteQ: Question"),
 		    tr("Your changes have not been saved. Continue closing?"),
-		    QMessageBox::Yes | QMessageBox::No,
+		    QMessageBox::No | QMessageBox::Yes,
 		    QMessageBox::No) == QMessageBox::No)
 	  {
 	    QApplication::processEvents();
@@ -388,7 +397,8 @@ void biblioteq_grey_literature::createFile(const QByteArray &bytes,
        __LINE__);
 }
 
-void biblioteq_grey_literature::duplicate(const QString &p_oid, const int state)
+void biblioteq_grey_literature::duplicate
+(const QString &p_oid, const int state)
 {
   m_duplicate = true;
   modify(state); // Initial population.
@@ -443,6 +453,7 @@ void biblioteq_grey_literature::insert(void)
   m_ui.type->setCurrentIndex(0);
   highlightRequiredWidgets();
   setWindowTitle(tr("BiblioteQ: Create Grey Literature Entry"));
+  prepareFavorites();
   storeData(this);
 #ifdef Q_OS_ANDROID
   showMaximized();
@@ -453,6 +464,7 @@ void biblioteq_grey_literature::insert(void)
 #endif
   activateWindow();
   raise();
+  prepareIcons(this);
 }
 
 void biblioteq_grey_literature::insertDatabase(void)
@@ -619,7 +631,6 @@ void biblioteq_grey_literature::modify(const int state)
       m_ui.delete_files->setVisible(false);
       m_ui.export_files->setEnabled(true);
       m_ui.okButton->setVisible(false);
-      m_ui.okButton->setVisible(false);
       m_ui.resetButton->setVisible(false);
 
       if(qmain->isGuest())
@@ -628,6 +639,8 @@ void biblioteq_grey_literature::modify(const int state)
 	m_ui.showUserButton->setEnabled(true);
     }
 
+  prepareIcons(this);
+
   QSqlQuery query(qmain->getDB());
 
   query.prepare("SELECT author, "
@@ -825,7 +838,8 @@ void biblioteq_grey_literature::populateFiles(void)
 	row += 1;
       }
 
-  m_ui.files->horizontalHeader()->setSortIndicator(FILE, Qt::AscendingOrder);
+  m_ui.files->horizontalHeader()->setSortIndicator
+    (static_cast<int> (Columns::FILE), Qt::AscendingOrder);
   m_ui.files->setRowCount(totalRows);
   m_ui.files->setSortingEnabled(true);
 
@@ -856,6 +870,18 @@ void biblioteq_grey_literature::populateFiles(void)
   QApplication::restoreOverrideCursor();
 }
 
+void biblioteq_grey_literature::prepareFavorites(void)
+{
+  QSettings settings;
+
+  m_ui.type->setCurrentIndex
+    (m_ui.type->findText(settings.value("grey_literature_types_favorite").
+			 toString().trimmed()));
+
+  if(m_ui.type->currentIndex() < 0)
+    m_ui.type->setCurrentIndex(0);
+}
+
 void biblioteq_grey_literature::search(const QString &field,
 				       const QString &value)
 {
@@ -874,10 +900,12 @@ void biblioteq_grey_literature::search(const QString &field,
   m_ui.showUserButton->setEnabled(false);
   m_ui.type->insertItem(0, tr("Any"));
   m_ui.type->setCurrentIndex(0);
+  prepareIcons(this);
 
   if(field.isEmpty() && value.isEmpty())
     {
       m_ui.title->setFocus();
+      prepareFavorites();
       setWindowTitle(tr("BiblioteQ: Database Grey Literature Search"));
 #ifdef Q_OS_ANDROID
       showMaximized();
@@ -945,7 +973,7 @@ void biblioteq_grey_literature::slotAttachFiles(void)
 
       for(int i = 0; i < files.size() && !progress.wasCanceled(); i++)
 	{
-	  QCryptographicHash digest(QCryptographicHash::Sha1);
+	  QCryptographicHash digest(QCryptographicHash::Sha3_512);
 	  QFile file;
 	  const auto &fileName(files.at(i));
 
@@ -994,25 +1022,27 @@ void biblioteq_grey_literature::slotCancel(void)
 
 void biblioteq_grey_literature::slotDeleteFiles(void)
 {
-  auto list(m_ui.files->selectionModel()->selectedRows(MYOID));
+  auto list(m_ui.files->selectionModel()->
+	    selectedRows(static_cast<int> (Columns::MYOID)));
 
   if(list.isEmpty())
     {
       QMessageBox::critical
-	(this, tr("BiblioteQ: User Error"),
+	(this,
+	 tr("BiblioteQ: User Error"),
 	 tr("Please select at least one file to delete."));
       QApplication::processEvents();
       return;
     }
 
-  if(QMessageBox::question(this, tr("BiblioteQ: Question"),
+  if(QMessageBox::question(this,
+			   tr("BiblioteQ: Question"),
 			   tr("Are you sure that you wish to delete the "
 			      "selected file(s)?"),
-			   QMessageBox::Yes | QMessageBox::No,
+			   QMessageBox::No | QMessageBox::Yes,
 			   QMessageBox::No) == QMessageBox::No)
     {
       QApplication::processEvents();
-      list.clear();
       return;
     }
 
@@ -1036,7 +1066,8 @@ void biblioteq_grey_literature::slotDeleteFiles(void)
 
 void biblioteq_grey_literature::slotExportFiles(void)
 {
-  auto list(m_ui.files->selectionModel()->selectedRows(MYOID));
+  auto list(m_ui.files->selectionModel()->
+	    selectedRows(static_cast<int> (Columns::MYOID)));
 
   if(list.isEmpty())
     return;
@@ -1103,9 +1134,11 @@ void biblioteq_grey_literature::slotFilesDoubleClicked(QTableWidgetItem *item)
   if(!item)
     return;
 
-  if(item->column() != DESCRIPTION || m_engWindowTitle != "Modify")
+  if(item->column() != static_cast<int> (Columns::DESCRIPTION) ||
+     m_engWindowTitle != "Modify")
     {
-      auto item1 = m_ui.files->item(item->row(), FILE);
+      auto item1 = m_ui.files->item
+	(item->row(), static_cast<int> (Columns::FILE));
 
       if(!item1)
 	return;
@@ -1146,13 +1179,15 @@ void biblioteq_grey_literature::slotFilesDoubleClicked(QTableWidgetItem *item)
   if(m_engWindowTitle != "Modify")
     return;
 
-  auto item1 = m_ui.files->item(item->row(), DESCRIPTION);
+  auto item1 = m_ui.files->item
+    (item->row(), static_cast<int> (Columns::DESCRIPTION));
 
   if(!item1)
     return;
 
   auto description(item1->text());
-  auto item2 = m_ui.files->item(item->row(), MYOID);
+  auto item2 = m_ui.files->item
+    (item->row(), static_cast<int> (Columns::MYOID));
 
   if(!item2)
     return;
@@ -1390,6 +1425,11 @@ void biblioteq_grey_literature::slotGo(void)
     }
 }
 
+void biblioteq_grey_literature::slotPrepareIcons(void)
+{
+  prepareIcons(this);
+}
+
 void biblioteq_grey_literature::slotPrint(void)
 {
   m_html = "<html>";
@@ -1842,7 +1882,8 @@ void biblioteq_grey_literature::updateWindow(const int state)
       m_ui.resetButton->setVisible(true);
       m_ui.showUserButton->setEnabled(true);
       string = QString(tr("BiblioteQ: Modify Grey Literature Entry (")) +
-	m_ui.id->text() + tr(")");
+	m_ui.id->text() +
+	tr(")");
     }
   else
     {
@@ -1859,7 +1900,8 @@ void biblioteq_grey_literature::updateWindow(const int state)
 	m_ui.showUserButton->setEnabled(true);
 
       string = QString(tr("BiblioteQ: View Grey Literature Details (")) +
-	m_ui.id->text() + tr(")");
+	m_ui.id->text() +
+	tr(")");
     }
 
   setReadOnlyFields(this, state != biblioteq::EDITABLE);
