@@ -28,6 +28,7 @@
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QProgressDialog>
+#include <QSettings>
 
 #include "biblioteq.h"
 #include "biblioteq_import.h"
@@ -74,6 +75,7 @@ biblioteq_import::biblioteq_import(biblioteq *parent):QMainWindow(parent)
 	  SIGNAL(currentIndexChanged(int)),
 	  this,
 	  SLOT(slotTemplates(int)));
+  prepareIcons();
 }
 
 void biblioteq_import::changeEvent(QEvent *event)
@@ -169,7 +171,7 @@ void biblioteq_import::importBooks(QProgressDialog *progress,
   QHash<QString, int> isbns;
   QTextStream in(&file);
   auto list(m_ui.ignored_rows->text().trimmed().split(' ',
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 						      Qt::SkipEmptyParts
 #else
 						      QString::SkipEmptyParts
@@ -370,7 +372,7 @@ void biblioteq_import::importBooks(QProgressDialog *progress,
 		  else if(m_mappings.value(i).first == "price")
 		    {
 		      QLocale locale;
-		      bool ok = true;
+		      auto ok = true;
 		      double price = locale.toDouble
 			(str.remove(locale.currencySymbol()), &ok);
 
@@ -384,6 +386,19 @@ void biblioteq_import::importBooks(QProgressDialog *progress,
 		      (1,
 		       str.toInt(),
 		       static_cast<int> (biblioteq::Limits::QUANTITY));
+		  else if(m_mappings.value(i).first == "target_audience")
+		    {
+		      if(!str.isEmpty())
+			{
+			  QSqlQuery query(m_qmain->getDB());
+
+			  query.prepare
+			    ("INSERT INTO book_target_audiences "
+			     "(target_audience) VALUES(?)");
+			  query.addBindValue(str);
+			  query.exec();
+			}
+		    }
 
 		  if(str.isEmpty())
 		    /*
@@ -543,7 +558,7 @@ void biblioteq_import::importPatrons(QProgressDialog *progress,
 
   QTextStream in(&file);
   auto list(m_ui.ignored_rows->text().trimmed().split(' ',
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 						      Qt::SkipEmptyParts
 #else
 						      QString::SkipEmptyParts
@@ -736,7 +751,8 @@ void biblioteq_import::loadPreview(void)
 	    {
 	      for(int i = 0; i < m_ui.rows->rowCount(); i++)
 		{
-		  auto item = m_ui.rows->item(i, CSV_PREVIEW);
+		  auto item = m_ui.rows->item
+		    (i, static_cast<int> (Columns::CSV_PREVIEW));
 
 		  if(item)
 		    item->setText(list.value(i));
@@ -769,6 +785,44 @@ void biblioteq_import::loadPreview(void)
   QApplication::processEvents();
 }
 
+void biblioteq_import::prepareIcons(void)
+{
+  QSettings setting;
+  auto index = setting.value("otheroptions/display_icon_set_index", 0).toInt();
+
+  if(index == 1)
+    {
+      // System.
+
+      m_ui.add_row->setIcon
+	(QIcon::fromTheme("list-add", QIcon(":/16x16/add.png")));
+      m_ui.close->setIcon
+	(QIcon::fromTheme("window-close", QIcon(":/32x32/cancel.png")));
+      m_ui.delete_row->setIcon
+	(QIcon::fromTheme("list-remove", QIcon(":/16x16/eraser.png")));
+      m_ui.import_csv->setIcon
+	(QIcon::fromTheme("document-import", QIcon(":/32x32/import.png")));
+      m_ui.refresh_preview->setIcon
+	(QIcon::fromTheme("view-refresh", QIcon(":/16x16/reload.png")));
+      m_ui.reset->setIcon
+	(QIcon::fromTheme("edit-reset", QIcon(":/32x32/reload.png")));
+      m_ui.select_csv_file->setIcon
+	(QIcon::fromTheme("document-open", QIcon(":/16x16/fileopen.png")));
+    }
+  else
+    {
+      // Faenza.
+
+      m_ui.add_row->setIcon(QIcon(":/16x16/add.png"));
+      m_ui.close->setIcon(QIcon(":/32x32/cancel.png"));
+      m_ui.delete_row->setIcon(QIcon(":/16x16/eraser.png"));
+      m_ui.import_csv->setIcon(QIcon(":/32x32/import.png"));
+      m_ui.refresh_preview->setIcon(QIcon(":/16x16/reload.png"));
+      m_ui.reset->setIcon(QIcon(":/32x32/reload.png"));
+      m_ui.select_csv_file->setIcon(QIcon(":/16x16/fileopen.png"));
+    }
+}
+
 void biblioteq_import::reset(void)
 {
   slotReset();
@@ -798,16 +852,19 @@ void biblioteq_import::slotAddRow(void)
 
   item->setText(QString::number(m_ui.rows->rowCount()));
   m_ui.rows->setItem
-    (m_ui.rows->rowCount() - 1, Columns::CSV_COLUMN_NUMBER, item);
+    (m_ui.rows->rowCount() - 1,
+     static_cast<int> (Columns::CSV_COLUMN_NUMBER),
+     item);
   item = new QTableWidgetItem
     (m_previewHeaders.value(m_ui.rows->rowCount() - 1));
   item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
-  m_ui.rows->setItem(m_ui.rows->rowCount() - 1, Columns::CSV_PREVIEW, item);
+  m_ui.rows->setItem
+    (m_ui.rows->rowCount() - 1, static_cast<int> (Columns::CSV_PREVIEW), item);
 
   auto comboBox = new QComboBox();
   auto widget = new QWidget();
 
-  switch(m_ui.templates->currentIndex())
+  switch(static_cast<Templates> (m_ui.templates->currentIndex()))
     {
     case Templates::TEMPLATE_1:
     case Templates::TEMPLATE_2:
@@ -821,6 +878,7 @@ void biblioteq_import::slotAddRow(void)
 			   << "callnumber"
 			   << "category"
 			   << "condition"
+			   << "date_of_reform"
 			   << "description"
 			   << "deweynumber"
 			   << "edition"
@@ -833,11 +891,13 @@ void biblioteq_import::slotAddRow(void)
 			   << "marc_tags"
 			   << "monetary_units"
 			   << "multivolume_set_isbn"
+			   << "origin"
 			   << "originality"
 			   << "pdate"
 			   << "place"
 			   << "price"
 			   << "publisher"
+			   << "purchase_date"
 			   << "quantity"
 			   << "target_audience"
 			   << "title"
@@ -888,11 +948,15 @@ void biblioteq_import::slotAddRow(void)
   layout->addSpacerItem(spacer);
   layout->setContentsMargins(0, 0, 0, 0);
   m_ui.rows->setCellWidget
-    (m_ui.rows->rowCount() - 1, Columns::BIBLIOTEQ_TABLE_FIELD_NAME, widget);
+    (m_ui.rows->rowCount() - 1,
+     static_cast<int> (Columns::BIBLIOTEQ_TABLE_FIELD_NAME),
+     widget);
   item = new QTableWidgetItem();
   item->setText("N/A");
   m_ui.rows->setItem
-    (m_ui.rows->rowCount() - 1, Columns::SUBSTITUTE_VALUE, item);
+    (m_ui.rows->rowCount() - 1,
+     static_cast<int> (Columns::SUBSTITUTE_VALUE),
+     item);
   m_ui.rows->resizeRowsToContents();
 
   if(m_ui.bottom_scroll_on_add->isChecked())
@@ -962,10 +1026,12 @@ void biblioteq_import::slotImport(void)
 
   for(int i = 0; i < m_ui.rows->rowCount(); i++)
     {
-      auto item1 = m_ui.rows->item(i, Columns::CSV_COLUMN_NUMBER);
-      auto item2 = m_ui.rows->item(i, Columns::SUBSTITUTE_VALUE);
+      auto item1 = m_ui.rows->item
+	(i, static_cast<int> (Columns::CSV_COLUMN_NUMBER));
+      auto item2 = m_ui.rows->item
+	(i, static_cast<int> (Columns::SUBSTITUTE_VALUE));
       auto widget = m_ui.rows->cellWidget
-	(i, Columns::BIBLIOTEQ_TABLE_FIELD_NAME);
+	(i, static_cast<int> (Columns::BIBLIOTEQ_TABLE_FIELD_NAME));
 
       if(!item1 || !item2 || !widget)
 	continue;
@@ -1017,7 +1083,7 @@ void biblioteq_import::slotImport(void)
   qint64 imported = 0;
   qint64 notImported = 0;
 
-  if(index == Templates::TEMPLATE_1)
+  if(index == static_cast<int> (Templates::TEMPLATE_1))
     /*
     ** ID's index is 1-based.
     */
@@ -1025,10 +1091,10 @@ void biblioteq_import::slotImport(void)
     importBooks(progress.data(),
 		errors,
 		Templates::TEMPLATE_1,
-		11,
+		12, // ISBN-10
 		&imported,
 		&notImported);
-  else if(index == Templates::TEMPLATE_2)
+  else if(index == static_cast<int> (Templates::TEMPLATE_2))
     /*
     ** ID's index is 1-based.
     */
@@ -1036,10 +1102,10 @@ void biblioteq_import::slotImport(void)
     importBooks(progress.data(),
 		errors,
 		Templates::TEMPLATE_2,
-		9,
+		9, // ISBN-10
 		&imported,
 		&notImported);
-  else if(index == Templates::TEMPLATE_3)
+  else if(index == static_cast<int> (Templates::TEMPLATE_3))
     importPatrons(progress.data(), errors, &imported, &notImported);
 
   progress->close();
@@ -1177,7 +1243,7 @@ void biblioteq_import::slotTemplates(int index)
 
 	QStringList list;
 
-	if(index == Templates::TEMPLATE_1)
+	if(index == static_cast<int> (Templates::TEMPLATE_1))
 	  list << "accession_number"
 	       << "alternate_id_1"
 	       << "author"
@@ -1185,6 +1251,7 @@ void biblioteq_import::slotTemplates(int index)
 	       << "callnumber"
 	       << "category"
 	       << "condition"
+	       << "date_of_reform"
 	       << "description"
 	       << "deweynumber"
 	       << "edition"
@@ -1197,17 +1264,19 @@ void biblioteq_import::slotTemplates(int index)
 	       << "marc_tags"
 	       << "monetary_units"
 	       << "multivolume_set_isbn"
+	       << "origin"
 	       << "originality"
 	       << "pdate"
 	       << "place"
 	       << "price"
 	       << "publisher"
+	       << "purchase_date"
 	       << "quantity"
 	       << "target_audience"
 	       << "title"
 	       << "url"
 	       << "volume_number";
-	else if(index == Templates::TEMPLATE_2)
+	else if(index == static_cast<int> (Templates::TEMPLATE_2))
 	  list << "title"
 	       << "author"
 	       << "publisher"
@@ -1232,8 +1301,12 @@ void biblioteq_import::slotTemplates(int index)
 	       << "condition"
 	       << "accession_number"
 	       << "alternate_id_1"
-	       << "volume_number";
-	else if(index == Templates::TEMPLATE_3)
+	       << "target_audience"
+	       << "volume_number"
+	       << "date_of_reform"
+	       << "origin"
+	       << "purchase_date";
+	else if(index == static_cast<int> (Templates::TEMPLATE_3))
 	  list << "city"
 	       << "comments"
 	       << "dob"
@@ -1261,14 +1334,15 @@ void biblioteq_import::slotTemplates(int index)
 
 	    if(list.at(i) == "id" || list.at(i) == "isbn13")
 	      {
-		auto item = m_ui.rows->item(i, Columns::SUBSTITUTE_VALUE);
+		auto item = m_ui.rows->item
+		  (i, static_cast<int> (Columns::SUBSTITUTE_VALUE));
 
 		if(item)
 		  item->setText("");
 	      }
 
 	    auto widget = m_ui.rows->cellWidget
-	      (i, Columns::BIBLIOTEQ_TABLE_FIELD_NAME);
+	      (i, static_cast<int> (Columns::BIBLIOTEQ_TABLE_FIELD_NAME));
 
 	    if(widget)
 	      {
