@@ -67,6 +67,7 @@ void biblioteq_marc::clear(void)
   m_targetAudience.clear();
   m_title.clear();
   m_volumeNumber.clear();
+  m_z3950Unimarc003.clear();
 }
 
 void biblioteq_marc::initialize(const ITEM_TYPE itemType,
@@ -1146,7 +1147,9 @@ void biblioteq_marc::parseBookZ3950Unimarc(void)
     {
       auto str = list[i];
 
-      if(str.startsWith("010 "))
+      if(str.startsWith("003 "))
+	m_z3950Unimarc003 = str.trimmed();
+      else if(str.startsWith("010 "))
 	{
 	  str = str.mid(4);
 
@@ -1351,18 +1354,22 @@ void biblioteq_marc::parseBookZ3950Unimarc(void)
 		m_place = m_place + "\n" + tmpstr;
 	    }
 
-	  if(str.indexOf("$d") > -1 &&
-	     str.mid(str.indexOf("$d") + 2, 4).toLower().
-	     contains("c"))
-	    m_publicationDate = QDate::fromString
-	      ("01/01/" +
-	       str.mid(str.indexOf("$d") + 4, 4),
-	       biblioteq::s_databaseDateFormat);
-	  else if(str.indexOf("$d") > -1)
-	    m_publicationDate = QDate::fromString
-	      ("01/01/" +
-	       str.mid(str.indexOf("$d") + 3, 4),
-	       biblioteq::s_databaseDateFormat);
+	  if(str.indexOf("$d") > -1)
+	    {
+	      QString s("");
+
+	      for(int i = str.indexOf("$d") + 2; i < str.length(); i++)
+		if(str[i].isDigit())
+		  {
+		    s.append(str[i]);
+
+		    if(s.length() == 4)
+		      break;
+		  }
+
+	      m_publicationDate = QDate::fromString
+		("01/01/" + s, biblioteq::s_databaseDateFormat);
+	    }
 
 	  if(str.contains("$c"))
 	    str = str.mid(str.indexOf("$c") + 2).trimmed();
@@ -1377,6 +1384,69 @@ void biblioteq_marc::parseBookZ3950Unimarc(void)
 
 	  m_publisher = str;
 	}
+      else if(str.startsWith("214 "))
+	{
+	  /*
+	  ** $a - Place of Publication
+	  ** $c - Name of Publisher
+	  ** $d - Publication Date
+	  */
+
+	  if(str.indexOf("$a") > -1)
+	    {
+	      auto s(str.mid(str.indexOf("$a") + 2).trimmed());
+
+	      if(s.indexOf("$b") > -1)
+		s = s.mid(0, s.indexOf("$b")).trimmed();
+	      else if(s.indexOf("$c") > -1)
+		s = s.mid(0, s.indexOf("$c")).trimmed();
+	      else if(s.indexOf("$d") > -1)
+		s = s.mid(0, s.indexOf("$d")).trimmed();
+	      else if(s.indexOf("$r") > -1)
+		s = s.mid(0, s.indexOf("$r")).trimmed();
+	      else if(s.indexOf("$s") > -1)
+		s = s.mid(0, s.indexOf("$s")).trimmed();
+
+	      if(m_place.isEmpty())
+		m_place = s;
+	      else
+		m_place += "\n" + s;
+	    }
+
+	  if(str.indexOf("$c") > -1)
+	    {
+	      auto s(str.mid(str.indexOf("$c") + 2).trimmed());
+
+	      if(s.indexOf("$d") > -1)
+		s = s.mid(0, s.indexOf("$d")).trimmed();
+	      else if(s.indexOf("$r") > -1)
+		s = s.mid(0, s.indexOf("$r")).trimmed();
+	      else if(s.indexOf("$s") > -1)
+		s = s.mid(0, s.indexOf("$s")).trimmed();
+
+	      if(m_publisher.isEmpty())
+		m_publisher = s;
+	      else
+		m_publisher += "\n" + s;
+	    }
+
+	  if(str.indexOf("$d") > -1)
+	    {
+	      QString s("");
+
+	      for(int i = str.indexOf("$d") + 2; i < str.length(); i++)
+		if(str[i].isDigit())
+		  {
+		    s.append(str[i]);
+
+		    if(s.length() == 4)
+		      break;
+		  }
+
+	      m_publicationDate = QDate::fromString
+		("01/01/" + s, biblioteq::s_databaseDateFormat);
+	    }
+	}
       else if(str.startsWith("215 "))
 	{
 	  str = str.mid(4);
@@ -1619,18 +1689,22 @@ void biblioteq_marc::parseMagazineZ3950Unimarc(void)
 		m_place = m_place + "\n" + tmpstr;
 	    }
 
-	  if(str.indexOf("$d") > -1 &&
-	     str.mid(str.indexOf("$d") + 2, 4).toLower().
-	     contains("c"))
-	    m_publicationDate = QDate::fromString
-	      ("01/01/" +
-	       str.mid(str.indexOf("$d") + 4, 4),
-	       biblioteq::s_databaseDateFormat);
-	  else if(str.indexOf("$d") > -1)
-	    m_publicationDate = QDate::fromString
-	      ("01/01/" +
-	       str.mid(str.indexOf("$d") + 3, 4),
-	       biblioteq::s_databaseDateFormat);
+	  if(str.indexOf("$d") > -1)
+	    {
+	      QString s("");
+
+	      for(int i = str.indexOf("$d") + 2; i < str.length(); i++)
+		if(str[i].isDigit())
+		  {
+		    s.append(str[i]);
+
+		    if(s.length() == 4)
+		      break;
+		  }
+
+	      m_publicationDate = QDate::fromString
+		("01/01/" + s, biblioteq::s_databaseDateFormat);
+	    }
 
 	  if(str.contains("$c"))
 	    str = str.mid(str.indexOf("$c") + 2).trimmed();
