@@ -694,7 +694,7 @@ QString biblioteq_misc_functions::isbn10to13(const QString &text)
 
   QList<int> array;
   QString numberstr("");
-  QString str("978" + QString(text).remove('-').trimmed().left(9));
+  auto str("978" + QString(text).remove('-').trimmed().left(9));
   int check = 0;
   int total = 0;
 
@@ -745,6 +745,30 @@ QString biblioteq_misc_functions::linearizeString(const QString &text)
   return text.simplified().replace("<br>", " ").simplified().trimmed();
 }
 
+QString biblioteq_misc_functions::queryString(QSqlQuery *query)
+{
+  if(!query)
+    return "";
+
+  int index = -1;
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+  auto list(query->boundValues());
+#else
+  auto list(query->boundValues().values());
+#endif
+  auto str(query->executedQuery());
+
+  while((index = str.indexOf('?')) >= 0 && list.size() > 0)
+    {
+      QString value(list.takeFirst().toString().toUtf8().data());
+
+      str.replace
+	(index, 1, value.isEmpty() ? "'%'" : QString("'%1'").arg(value));
+    }
+
+  return str;
+}
+
 QStringList biblioteq_misc_functions::getBookBindingTypes
 (const QSqlDatabase &db, QString &errorstr)
 {
@@ -1043,7 +1067,6 @@ QStringList biblioteq_misc_functions::getMinimumDays(const QSqlDatabase &db,
   for(int i = 0; i < map.values().size(); i++)
     minimumdays.append(map.values().at(i));
 
-  map.clear();
   return minimumdays;
 }
 
@@ -1283,11 +1306,16 @@ bool biblioteq_misc_functions::getMemberMatch(const QString &checksum,
   auto exists = false;
 
   errorstr = "";
-  querystr = "SELECT EXISTS(SELECT 1 FROM member "
-    "WHERE "
-    "dob || sex || first_name || "
+  querystr = "SELECT EXISTS(SELECT 1 FROM member WHERE "
+    "city || "
+    "dob || "
+    "first_name || "
+    "last_name || "
     "middle_init || "
-    "last_name || street || city || state_abbr || zip = ? "
+    "sex || "
+    "state_abbr || "
+    "street || "
+    "zip = ? "
     "AND memberid != ?)";
   query.prepare(querystr);
   query.bindValue(0, checksum);
@@ -1810,8 +1838,8 @@ int biblioteq_misc_functions::quantity
 (const QSqlDatabase &db, const QString &oid, const QString &t)
 {
   QSqlQuery query(db);
-  QString type(QString(t).remove(' ').toLower());
   QString querystr = "";
+  auto type(QString(t).remove(' ').toLower());
 
   if(type == "greyliterature")
     querystr = "SELECT quantity FROM grey_literature WHERE myoid = ?";
@@ -2354,8 +2382,8 @@ void biblioteq_misc_functions::exportPhotographs
 	  QImage image;
 	  auto bytes
 	    (QByteArray::fromBase64(query.value(0).toByteArray()));
-	  auto id = QDateTime::currentMSecsSinceEpoch();
 	  auto format(imageFormatGuess(bytes));
+	  auto id = QDateTime::currentMSecsSinceEpoch();
 
 	  image.loadFromData(bytes, format.toLatin1().constData());
 
@@ -2413,9 +2441,9 @@ void biblioteq_misc_functions::exportPhotographs
       else
 	progress.setMaximum(0);
 
+      auto id = QDateTime::currentMSecsSinceEpoch();
       int i = 0;
       int j = -1;
-      auto id = QDateTime::currentMSecsSinceEpoch();
 
       while(query.next())
 	{
@@ -2747,8 +2775,10 @@ void biblioteq_misc_functions::sortCombinationBox(QComboBox *comboBox)
     list << comboBox->itemText(i);
 
   std::sort(list.begin(), list.end());
+  comboBox->blockSignals(true);
   comboBox->clear();
   comboBox->addItems(list);
+  comboBox->blockSignals(false);
 }
 
 void biblioteq_misc_functions::updateColumn(QTableWidget *table,
