@@ -276,11 +276,6 @@ void biblioteq_otheroptions::changeEvent(QEvent *event)
   QMainWindow::changeEvent(event);
 }
 
-void biblioteq_otheroptions::closeEvent(QCloseEvent *event)
-{
-  QMainWindow::closeEvent(event);
-}
-
 void biblioteq_otheroptions::keyPressEvent(QKeyEvent *event)
 {
   if(event && event->key() == Qt::Key_Escape)
@@ -352,6 +347,7 @@ void biblioteq_otheroptions::prepareAvailability(void)
       item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
       m_ui.availability_color->setCellWidget(i, AVAILABILITY_COLOR, widget);
       m_ui.availability_color->setItem(i, ITEM_TYPE, item);
+      pushButton->setMinimumWidth(135);
       pushButton->setText(list2.at(i));
       pushButton->setStyleSheet
 	(QString("background-color: %1").arg(QString(list2.at(i)).remove('&')));
@@ -363,6 +359,29 @@ void biblioteq_otheroptions::prepareAvailability(void)
   m_ui.availability_color->sortByColumn(0, Qt::AscendingOrder);
 }
 
+void biblioteq_otheroptions::prepareIcons(void)
+{
+  if(m_ui.display_icon_set->currentIndex() == 1)
+    {
+      // System.
+
+      m_ui.close->setIcon
+	(QIcon::fromTheme("window-close", QIcon(":/16x16/cancel.png")));
+      m_ui.custom_query_reset->setIcon
+	(QIcon::fromTheme("edit-reset", QIcon(":/16x16/reset.png")));
+      m_ui.save->setIcon
+	(QIcon::fromTheme("document-save", QIcon(":/16x16/ok.png")));
+    }
+  else
+    {
+      // Faenza.
+
+      m_ui.close->setIcon(QIcon(":/16x16/cancel.png"));
+      m_ui.custom_query_reset->setIcon(QIcon(":/16x16/reset.png"));
+      m_ui.save->setIcon(QIcon(":/16x16/ok.png"));
+    }
+}
+
 void biblioteq_otheroptions::prepareMembersVisibleColumns(QTableWidget *table)
 {
   if(!table)
@@ -473,6 +492,7 @@ void biblioteq_otheroptions::prepareSettings(void)
 {
   QApplication::setOverrideCursor(Qt::WaitCursor);
   prepareAvailability();
+  prepareIcons();
   prepareShortcuts();
 
   QSettings settings;
@@ -571,6 +591,10 @@ void biblioteq_otheroptions::prepareSettings(void)
     (qBound(0,
 	    settings.value("otheroptions/books_accession_number_index").toInt(),
 	    m_ui.books_accession_number->count() - 1));
+  m_ui.display_icon_set->setCurrentIndex
+    (qBound(0,
+	    settings.value("otheroptions/display_icon_set_index", 0).toInt(),
+	    m_ui.display_icon_set->count() - 1));
   m_ui.generated_letter->setPlainText
     (QString::
      fromUtf8(QByteArray::
@@ -690,6 +714,7 @@ void biblioteq_otheroptions::prepareShortcuts(void)
 	item->setFlags
 	  (Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 
+      item->setToolTip(item->text());
       m_ui.shortcuts->setItem(i, 1, item);
     }
 
@@ -894,6 +919,8 @@ void biblioteq_otheroptions::slotSave(void)
        m_ui.shortcuts->item(i, 0)->text() == tr("Custom Query Favorite") &&
        m_ui.shortcuts->item(i, 1))
       {
+	m_ui.shortcuts->item(i, 1)->setToolTip
+	  (m_ui.shortcuts->item(i, 1)->text().trimmed());
 	settings.setValue
 	  ("custom_query_favorite_shortcut",
 	   m_ui.shortcuts->item(i, 1)->text().trimmed());
@@ -908,6 +935,9 @@ void biblioteq_otheroptions::slotSave(void)
   settings.setValue
     ("otheroptions/books_accession_number_index",
      m_ui.books_accession_number->currentIndex());
+  settings.setValue
+    ("otheroptions/display_icon_set_index",
+     m_ui.display_icon_set->currentIndex());
   settings.setValue
     ("otheroptions/generated_letter",
      m_ui.generated_letter->toPlainText().toUtf8().toBase64());
@@ -934,11 +964,18 @@ void biblioteq_otheroptions::slotSave(void)
   settings.setValue
     ("show_maintable_tooltips", m_ui.show_maintable_tooltips->isChecked());
   settings.sync();
+
+  if(settings.status() == QSettings::NoError)
+    m_ui.save->animate(2500);
+  else
+    m_ui.save->animateNegatively(2500);
+
   m_isbn10Format = m_ui.isbn10_display_format->currentText();
   m_isbn13Format = m_ui.isbn13_display_format->currentText();
   emit mainWindowCanvasBackgroundColorChanged
     (QColor(m_ui.main_window_canvas_background_color->text().remove('&')));
   emit saved();
+  prepareIcons();
   QApplication::restoreOverrideCursor();
 }
 
