@@ -42,6 +42,7 @@ CREATE TABLE book							\
     callnumber	 VARCHAR(64),						\
     category	 TEXT NOT NULL,						\
     condition    TEXT,							\
+    date_of_reform VARCHAR(32),						\
     description	 TEXT NOT NULL,						\
     deweynumber	 VARCHAR(64),						\
     edition	 VARCHAR(8) NOT NULL,					\
@@ -56,11 +57,13 @@ CREATE TABLE book							\
     monetary_units	 VARCHAR(64) NOT NULL DEFAULT 'UNKNOWN',	\
     multivolume_set_isbn VARCHAR(32),					\
     myoid	 BIGINT NOT NULL,					\
+    origin TEXT,							\
     originality  TEXT,							\
     pdate	 VARCHAR(32) NOT NULL,					\
     place	 TEXT NOT NULL,						\
     price	 NUMERIC(10, 2) NOT NULL DEFAULT 0.00,			\
     publisher	 TEXT NOT NULL,						\
+    purchase_date VARCHAR(32),						\
     quantity	 INTEGER NOT NULL DEFAULT 1,				\
     target_audience TEXT,						\
     title	 TEXT NOT NULL,						\
@@ -71,11 +74,12 @@ CREATE TABLE book							\
 									\
 CREATE TABLE book_copy_info						\
 (									\
+    condition    TEXT,							\
     copy_number	 INTEGER NOT NULL DEFAULT 1,				\
     copyid	 VARCHAR(64) NOT NULL,					\
-    myoid	 BIGINT NOT NULL,					\
-    condition    TEXT,							\
     item_oid	 BIGINT NOT NULL,					\
+    myoid	 BIGINT NOT NULL,					\
+    notes        TEXT,							\
     originality  TEXT,							\
     status       TEXT,							\
     PRIMARY KEY(item_oid, copyid),					\
@@ -132,6 +136,7 @@ CREATE TABLE cd_copy_info						\
     copyid	 VARCHAR(64) NOT NULL,					\
     item_oid	 BIGINT NOT NULL,					\
     myoid	 BIGINT NOT NULL,					\
+    notes        TEXT,							\
     status	 TEXT,							\
     PRIMARY KEY(item_oid, copyid),					\
     FOREIGN KEY(item_oid) REFERENCES cd(myoid) ON DELETE CASCADE	\
@@ -185,6 +190,7 @@ CREATE TABLE dvd_copy_info						\
     copyid	 VARCHAR(64) NOT NULL,					\
     item_oid	 BIGINT NOT NULL,					\
     myoid	 BIGINT NOT NULL,					\
+    notes        TEXT,							\
     status       TEXT,							\
     PRIMARY KEY(item_oid, copyid),					\
     FOREIGN KEY(item_oid) REFERENCES dvd(myoid) ON DELETE CASCADE	\
@@ -258,6 +264,7 @@ CREATE TABLE journal_copy_info						\
     copyid	 VARCHAR(64) NOT NULL,					\
     item_oid	 BIGINT NOT NULL,					\
     myoid	 BIGINT NOT NULL,					\
+    notes        TEXT,							\
     status       TEXT,							\
     PRIMARY KEY(item_oid, copyid),					\
     FOREIGN KEY(item_oid) REFERENCES journal(myoid) ON DELETE CASCADE	\
@@ -310,6 +317,7 @@ CREATE TABLE magazine_copy_info						\
     copyid	 VARCHAR(64) NOT NULL,					\
     item_oid	 BIGINT NOT NULL,					\
     myoid	 BIGINT NOT NULL,					\
+    notes        TEXT,							\
     status       TEXT,							\
     PRIMARY KEY(item_oid, copyid),				        \
     FOREIGN KEY(item_oid) REFERENCES magazine(myoid) ON DELETE CASCADE	\
@@ -395,10 +403,11 @@ CREATE TABLE videogame							\
 									\
 CREATE TABLE videogame_copy_info					\
 (									\
-    copy_number INTEGER NOT NULL DEFAULT 1,				\
+    copy_number  INTEGER NOT NULL DEFAULT 1,				\
     copyid	 VARCHAR(64) NOT NULL,					\
     item_oid	 BIGINT NOT NULL,					\
     myoid	 BIGINT NOT NULL,					\
+    notes        TEXT,							\
     status       TEXT,							\
     PRIMARY KEY(item_oid, copyid),				        \
     FOREIGN KEY(item_oid) REFERENCES videogame(myoid) ON		\
